@@ -69,7 +69,7 @@ GetChildAs(EbmlMaster *m) {
   return GetChild<A>(*m);
 }
 
-#define VERSIONNAME "Oh My God"
+#define VERSIONNAME "Stranger in your Soul"
 #define VERSIONINFO "mkvmerge v" VERSION " ('" VERSIONNAME "')"
 #define BUGMSG Y("This should not have happened. Please contact the author " \
                  "Moritz Bunkus <moritz@bunkus.org> with this error/warning " \
@@ -153,12 +153,10 @@ void MTX_DLL_API utf8_done();
 string MTX_DLL_API to_utf8(int handle, const string &local);
 string MTX_DLL_API from_utf8(int handle, const string &utf8);
 
-void MTX_DLL_API init_locales();
-
 vector<string> MTX_DLL_API command_line_utf8(int argc, char **argv);
 extern string MTX_DLL_API usage_text, version_info;
 void MTX_DLL_API usage(int exit_code = 0);
-void MTX_DLL_API handle_common_cli_args(vector<string> &args,
+bool MTX_DLL_API handle_common_cli_args(vector<string> &args,
                                         const string &redirect_output_short);
 
 enum unique_id_category_e {
