@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: dts_common.cpp 3843 2008-08-23 14:49:28Z mosu $
-
    helper function for DTS data
 
    Written by Peter Niemayer <niemayer@isg.de>.
@@ -93,7 +91,7 @@ find_dts_header_internal(const unsigned char *buf,
     return -1;
   }
 
-  unsigned int offset;
+  int offset;
   for (offset = 0; offset < size_to_search; ++offset)
      // sync words appear aligned in the bit stream
     if (get_uint32_be(buf + offset) == DTS_HEADER_MAGIC)
@@ -118,14 +116,14 @@ find_dts_header_internal(const unsigned char *buf,
 
   t = bc.get_bits(7);
   if (t < 5)  {
-    mxwarn("DTS_Header problem: invalid number of blocks in frame\n");
+    mxwarn(Y("DTS_Header problem: invalid number of blocks in frame\n"));
     //return -1;
   }
   dts_header->num_pcm_sample_blocks = t + 1;
 
   t = bc.get_bits(14);
   if (t < 95) {
-    mxwarn("DTS_Header problem: invalid frame bytes size\n");
+    mxwarn(Y("DTS_Header problem: invalid frame bytes size\n"));
     return -1;
   }
   dts_header->frame_byte_size = t+1;
@@ -143,7 +141,7 @@ find_dts_header_internal(const unsigned char *buf,
   t = bc.get_bits(4);
   dts_header->core_sampling_frequency = core_samplefreqs[t];
   if (dts_header->core_sampling_frequency < 0) {
-    mxwarn("DTS_Header problem: invalid core sampling frequency\n");
+    mxwarn(Y("DTS_Header problem: invalid core sampling frequency\n"));
     return -1;
   }
 
@@ -179,7 +177,7 @@ find_dts_header_internal(const unsigned char *buf,
   t = bc.get_bits(4);
   dts_header->encoder_software_revision = t;
   if (t > 7) {
-    mxwarn("DTS_Header problem: encoded with an incompatible new encoder version\n");
+    mxwarn(Y("DTS_Header problem: encoded with an incompatible new encoder version\n"));
     return -1;
   }
 
@@ -219,7 +217,7 @@ find_dts_header_internal(const unsigned char *buf,
       break;
 
     default:
-      mxwarn("DTS_Header problem: invalid source PCM resolution\n");
+      mxwarn(Y("DTS_Header problem: invalid source PCM resolution\n"));
       return -1;
   }
 
@@ -249,9 +247,21 @@ find_dts_header_internal(const unsigned char *buf,
   if (get_uint32_be(buf + hd_offset) != DTS_HD_HEADER_MAGIC)
     return offset;
 
-  dts_header->dts_hd           = true;
-  dts_header->hd_type          = (buf[hd_offset + 5] & 0x80) ? dts_header_t::DTSHD_MASTER_AUDIO : dts_header_t::DTSHD_HIGH_RESOLUTION;
-  dts_header->hd_part_size     = ((unsigned int)(buf[hd_offset + 6] & 0x0f) << 11) + ((unsigned int)buf[hd_offset + 7] << 3) + ((buf[hd_offset + 8] >> 5) & 0x07) + 1;
+  dts_header->dts_hd  = true;
+
+  bc.init(buf + hd_offset, size - hd_offset);
+
+  bc.skip_bits(32);             // DTS_HD_HEADER_MAGIC
+  bc.skip_bits(8 + 2);          // ??
+  if (bc.get_bit()) {           // Blown-up header bit
+    bc.skip_bits(12);
+    dts_header->hd_part_size = bc.get_bits(20) + 1;
+
+  } else {
+    bc.skip_bits(8);
+    dts_header->hd_part_size = bc.get_bits(16) + 1;
+  }
+
   dts_header->frame_byte_size += dts_header->hd_part_size;
 
   return offset;
@@ -265,7 +275,7 @@ find_dts_header(const unsigned char *buf,
   try {
     return find_dts_header_internal(buf, size, dts_header, allow_no_hd_search);
   } catch (...) {
-    mxwarn("DTS_Header problem: not enough data to read header\n");
+    mxwarn(Y("DTS_Header problem: not enough data to read header\n"));
     return -1;
   }
 }
@@ -280,47 +290,33 @@ print_dts_header(const struct dts_header_s *h) {
   if (h->frametype == dts_header_s::FRAMETYPE_NORMAL) {
     mxinfo("normal");
   } else {
-    mxinfo("termination, deficit sample count = %u",
-           h->deficit_sample_count);
+    mxinfo(boost::format("termination, deficit sample count = %1%") % h->deficit_sample_count);
   }
   mxinfo("\n");
 
-  mxinfo("CRC available          : %s\n", (h->crc_present)? "yes" : "no");
+  mxinfo(boost::format("CRC available          : %1%\n") % (h->crc_present ? "yes" : "no"));
 
-  mxinfo("Frame Size             : PCM core samples=32*%u=%u, %f "
-         "milliseconds, %u byte\n",
-         h->num_pcm_sample_blocks, h->num_pcm_sample_blocks * 32,
-         (h->num_pcm_sample_blocks * 32000.0) / h->core_sampling_frequency,
-         h->frame_byte_size);
+  mxinfo(boost::format("Frame Size             : PCM core samples=32*%1%=%2%, %3% milliseconds, %4% byte\n")
+         % h->num_pcm_sample_blocks % (h->num_pcm_sample_blocks * 32) % ((h->num_pcm_sample_blocks * 32000.0) / h->core_sampling_frequency) % h->frame_byte_size);
 
-  mxinfo("Audio Channels         : %d%s, arrangement: %s\n",
-         h->audio_channels, (h->source_surround_in_es)? " ES" : "" ,
-         h->audio_channel_arrangement);
+  mxinfo(boost::format("Audio Channels         : %1%%2%, arrangement: %3%\n")
+         % h->audio_channels % (h->source_surround_in_es ? " ES" : "") % h->audio_channel_arrangement);
 
-  mxinfo("Core sampling frequency: %u\n", h->core_sampling_frequency);
+  mxinfo(boost::format("Core sampling frequency: %1%\n") % h->core_sampling_frequency);
 
-  mxinfo("Transmission_bitrate   : ");
-  if (h->transmission_bitrate == -1)
-    mxinfo("open");
-  else if (h->transmission_bitrate == -2)
-    mxinfo("variable");
-  else if (h->transmission_bitrate == -3)
-    mxinfo("lossless");
+  if ((-1 < h->transmission_bitrate) || (-3 > h->transmission_bitrate))
+    mxinfo(boost::format("Transmission bitrate   : %1%\n") % h->transmission_bitrate);
   else
-    mxinfo("%d", h->transmission_bitrate);
-  mxinfo("\n");
+    mxinfo(boost::format("Transmission_bitrate   : %1%\n")
+           % (  h->transmission_bitrate == -1 ? "open"
+              : h->transmission_bitrate == -2 ? "variable"
+              :                                 "lossless"));
 
-
-  mxinfo("Embedded Down Mix      : %s\n",
-         (h->embedded_down_mix)? "yes" : "no");
-  mxinfo("Embedded Dynamic Range : %s\n",
-         (h->embedded_dynamic_range)? "yes" : "no");
-  mxinfo("Embedded Time Stamp    : %s\n",
-         (h->embedded_time_stamp)? "yes" : "no");
-  mxinfo("Embedded Auxiliary Data: %s\n",
-         (h->auxiliary_data)? "yes" : "no");
-  mxinfo("HDCD Master            : %s\n",
-         (h->hdcd_master)? "yes" : "no");
+  mxinfo(boost::format("Embedded Down Mix      : %1%\n") % (h->embedded_down_mix      ? "yes" : "no"));
+  mxinfo(boost::format("Embedded Dynamic Range : %1%\n") % (h->embedded_dynamic_range ? "yes" : "no"));
+  mxinfo(boost::format("Embedded Time Stamp    : %1%\n") % (h->embedded_time_stamp    ? "yes" : "no"));
+  mxinfo(boost::format("Embedded Auxiliary Data: %1%\n") % (h->auxiliary_data         ? "yes" : "no"));
+  mxinfo(boost::format("HDCD Master            : %1%\n") % (h->hdcd_master            ? "yes" : "no"));
 
   mxinfo("Extended Coding        : ");
   if (h->extended_coding) {
@@ -342,8 +338,7 @@ print_dts_header(const struct dts_header_s *h) {
     mxinfo("no");
   mxinfo("\n");
 
-  mxinfo("Audio Sync in sub-subs : %s\n",
-         (h->audio_sync_word_in_sub_sub)? "yes" : "no");
+  mxinfo(boost::format("Audio Sync in sub-subs : %1%\n") % (h->audio_sync_word_in_sub_sub ? "yes" : "no"));
 
   mxinfo("Low Frequency Effects  : ");
   switch (h->lfe_type) {
@@ -362,30 +357,22 @@ print_dts_header(const struct dts_header_s *h) {
   }
   mxinfo("\n");
 
-  mxinfo("Predictor History used : %s\n",
-         (h->predictor_history_flag)? "yes" : "no");
+  mxinfo(boost::format("Predictor History used : %1%\n") % (h->predictor_history_flag ? "yes" : "no"));
 
-  mxinfo("Multirate Interpolator : %s\n",
-         (h->multirate_interpolator == dts_header_s::MI_NON_PERFECT)?
-         "non perfect" : "perfect");
+  mxinfo(boost::format("Multirate Interpolator : %1%\n") % (h->multirate_interpolator == dts_header_s::MI_NON_PERFECT ? "non perfect" : "perfect"));
 
-  mxinfo("Encoder Software Vers. : %u\n",
-         h->encoder_software_revision);
-  mxinfo("Copy History Bits      : %u\n", h->copy_history);
-  mxinfo("Source PCM Resolution  : %d\n", h->source_pcm_resolution);
-
-  mxinfo("Front Encoded as Diff. : %s\n",
-         (h->front_sum_difference)? "yes" : "no");
-  mxinfo("Surr. Encoded as Diff. : %s\n",
-         (h->surround_sum_difference)? "yes" : "no");
-
-  mxinfo("Dialog Normaliz. Gain  : %d\n",
-         h->dialog_normalization_gain);
+  mxinfo(boost::format("Encoder Software Vers. : %1%\n") % h->encoder_software_revision);
+  mxinfo(boost::format("Copy History Bits      : %1%\n") % h->copy_history);
+  mxinfo(boost::format("Source PCM Resolution  : %1%\n") % h->source_pcm_resolution);
+  mxinfo(boost::format("Front Encoded as Diff. : %1%\n") % (h->front_sum_difference    ? "yes" : "no"));
+  mxinfo(boost::format("Surr. Encoded as Diff. : %1%\n") % (h->surround_sum_difference ? "yes" : "no"));
+  mxinfo(boost::format("Dialog Normaliz. Gain  : %1%\n") % h->dialog_normalization_gain);
 
   if (!h->dts_hd)
     mxinfo("DTS HD                 : no\n");
   else
-    mxinfo("DTS HD                 : %s, size %d\n", h->hd_type == dts_header_t::DTSHD_MASTER_AUDIO ? "master audio" : "high resolution", h->hd_part_size);
+    mxinfo(boost::format("DTS HD                 : %1%, size %2%\n")
+           % (h->hd_type == dts_header_t::DTSHD_MASTER_AUDIO ? "master audio" : "high resolution") % h->hd_part_size);
 }
 
 void
