@@ -112,7 +112,7 @@ const iso639_language_t iso639_languages[] = {
   { "Chuang; Zhuang",                                 "zha", "za", NULL  },
   { "Church Slavic; Old Church Slavonic",             "chu", "cu", NULL  },
   { "Church Slavic; Old Church Slavonic",             "chu", "cu", NULL  },
-  { "Church Slavonic; Old Bulgarian; Church Slavic;", "chu", "cu", NULL  },
+  { "Church Slavonic; Old Bulgarian; Church Slavic",  "chu", "cu", NULL  },
   { "Chuukese",                                       "chk", NULL, NULL  },
   { "Chuvash",                                        "chv", "cv", NULL  },
   { "Classical Newari; Classical Nepal Bhasa",        "nwc", NULL, NULL  },
@@ -123,9 +123,9 @@ const iso639_language_t iso639_languages[] = {
   { "Cree",                                           "cre", "cr", NULL  },
   { "Creek",                                          "mus", NULL, NULL  },
   { "Creoles and pidgins (Other)",                    "crp", NULL, NULL  },
-  { "Creoles and pidgins,",                           "cpe", NULL, NULL  },
-  { "Creoles and pidgins,",                           "cpf", NULL, NULL  },
-  { "Creoles and pidgins,",                           "cpp", NULL, NULL  },
+  { "Creoles and pidgins",                            "cpe", NULL, NULL  },
+  { "Creoles and pidgins",                            "cpf", NULL, NULL  },
+  { "Creoles and pidgins",                            "cpp", NULL, NULL  },
   { "Crimean Tatar; Crimean Turkish",                 "crh", NULL, NULL  },
   { "Croatian; Hrvatske",                             "scr", "hr", "hrv" },
   { "Cushitic (Other)",                               "cus", NULL, NULL  },
@@ -284,7 +284,7 @@ const iso639_language_t iso639_languages[] = {
   { "Letzeburgesch; Luxembourgish",                   "ltz", "lb", NULL  },
   { "Lezghian",                                       "lez", NULL, NULL  },
   { "Limburgan; Limburger; Limburgish",               "lim", "li", NULL  },
-  { "Limburger; Limburgan; Limburgish;",              "lim", "li", NULL  },
+  { "Limburger; Limburgan; Limburgish",               "lim", "li", NULL  },
   { "Limburgish; Limburger; Limburgan",               "lim", "li", NULL  },
   { "Lingala",                                        "lin", "ln", NULL  },
   { "Lithuanian",                                     "lit", "lt", NULL  },
@@ -370,9 +370,9 @@ const iso639_language_t iso639_languages[] = {
   { "Nzima",                                          "nzi", NULL, NULL  },
   { "Occitan (post 1500)",                            "oci", "oc", NULL  },
   { "Ojibwa",                                         "oji", "oj", NULL  },
-  { "Old Bulgarian; Old Slavonic; Church Slavonic;",  "chu", "cu", NULL  },
-  { "Old Church Slavonic; Old Slavonic; ",            "chu", "cu", NULL  },
-  { "Old Slavonic; Church Slavonic; Old Bulgarian;",  "chu", "cu", NULL  },
+  { "Old Bulgarian; Old Slavonic; Church Slavonic",   "chu", "cu", NULL  },
+  { "Old Church Slavonic; Old Slavonic",              "chu", "cu", NULL  },
+  { "Old Slavonic; Church Slavonic; Old Bulgarian",   "chu", "cu", NULL  },
   { "Oriya",                                          "ori", "or", NULL  },
   { "Oromo",                                          "orm", "om", NULL  },
   { "Osage",                                          "osa", NULL, NULL  },
@@ -535,9 +535,7 @@ const iso639_language_t iso639_languages[] = {
 
 bool
 is_valid_iso639_2_code(const char *iso639_2_code) {
-  int i;
-
-  i = 0;
+  int i = 0;
   while (iso639_languages[i].iso639_2_code != NULL) {
     if (!strcmp(iso639_languages[i].iso639_2_code, iso639_2_code))
       return true;
@@ -549,9 +547,7 @@ is_valid_iso639_2_code(const char *iso639_2_code) {
 
 void
 list_iso639_languages() {
-  int i;
-
-  i = 0;
+  int i = 0;
   mxinfo(Y("                             English language name | ISO639-2 code | ISO639-1 code\n"
            "---------------------------------------------------+---------------+--------------\n"));
   while (iso639_languages[i].iso639_2_code != NULL) {
