@@ -50,6 +50,7 @@
 #include "mkvextract.h"
 #include "mm_io.h"
 #include "tagwriter.h"
+#include "translation.h"
 #include "xml_element_mapping.h"
 
 using namespace libmatroska;
@@ -154,7 +155,9 @@ parse_args(vector<string> args,
 
   verbose = 0;
 
-  handle_common_cli_args(args, "-o");
+  set_usage();
+  while (handle_common_cli_args(args, "-o"))
+    set_usage();
 
   if (args.empty())
     usage();
@@ -335,7 +338,6 @@ main(int argc,
      char **argv) {
   init_stdio();
   init_locales();
-  set_usage();
 
 #if defined(SYS_UNIX)
   nice(2);
@@ -356,7 +358,7 @@ main(int argc,
     extract_tracks(input_file.c_str(), tracks);
 
     if (0 == verbose)
-      mxinfo(Y("Progress: 100%%\n"));
+      mxinfo(Y("Progress: 100%\n"));
 
   } else if (MODE_TAGS == mode)
     extract_tags(input_file.c_str(), s_parse_fully);
