@@ -77,6 +77,7 @@ extern "C" {
 #include "commonebml.h"
 #include "matroska.h"
 #include "mm_io.h"
+#include "translation.h"
 #include "xml_element_mapping.h"
 
 using namespace libmatroska;
@@ -247,7 +248,9 @@ parse_args(vector<string> args,
 
   use_gui = false;
 
-  handle_common_cli_args(args, "-o");
+  set_usage();
+  while (handle_common_cli_args(args, "-o"))
+    set_usage();
 
   // Now parse the rest of the arguments.
   for (i = 0; i < args.size(); i++)
@@ -1839,10 +1842,9 @@ process_file(const string &file_name) {
 }
 
 void
-setup() {
+setup(const std::string &locale) {
   init_stdio();
-  init_locales();
-  set_usage();
+  init_locales(locale);
 
   mm_file_io_c::setup();
   cc_local_utf8 = utf8_init("");
