@@ -1124,6 +1124,23 @@ generic_reader_c::demuxing_requested(char type,
   return false;
 }
 
+attach_mode_e
+generic_reader_c::attachment_requested(int64_t id) {
+  if (ti.no_attachments)
+    return ATTACH_MODE_SKIP;
+
+  if (ti.attach_mode_list.empty())
+    return ATTACH_MODE_TO_ALL_FILES;
+
+  if (map_has_key(ti.attach_mode_list, id))
+    return ti.attach_mode_list[id];
+
+  if (map_has_key(ti.attach_mode_list, -1))
+    return ti.attach_mode_list[-1];
+
+  return ATTACH_MODE_SKIP;
+}
+
 int
 generic_reader_c::add_packetizer(generic_packetizer_c *ptzr) {
   reader_packetizers.push_back(ptzr);
@@ -1289,9 +1306,9 @@ generic_reader_c::display_identification_results() {
   if (g_identify_for_mmg) {
     format_file            =   "File '%1%': container: %2%";
     format_track           =   "Track ID %1%: %2% (%3%)";
-    format_attachment      =   "Attachment ID %1%: type '%2%', size %3% bytes";
-    format_att_description =   ", description '%1%'";
-    format_att_file_name   =   ", file name '%1%'";
+    format_attachment      =   "Attachment ID %1%: type \"%2%\", size %3% bytes";
+    format_att_description =   ", description \"%1%\"";
+    format_att_file_name   =   ", file name \"%1%\"";
 
   } else {
     format_file            = Y("File '%1%': container: %2%");
@@ -1323,18 +1340,23 @@ generic_reader_c::display_identification_results() {
   for (i = 0; i < id_results_attachments.size(); ++i) {
     id_result_t &result = id_results_attachments[i];
 
-    mxinfo(boost::format(format_attachment) % result.id % result.type % result.size);
+    mxinfo(boost::format(format_attachment) % result.id % id_escape_string(result.type) % result.size);
 
     if (!result.description.empty())
-      mxinfo(boost::format(format_att_description) % result.description);
+      mxinfo(boost::format(format_att_description) % id_escape_string(result.description));
 
     if (!result.info.empty())
-      mxinfo(boost::format(format_att_file_name) % result.info);
+      mxinfo(boost::format(format_att_file_name) % id_escape_string(result.info));
 
     mxinfo("\n");
   }
 }
 
+std::string
+generic_reader_c::id_escape_string(const std::string &s) {
+  return g_identify_for_mmg ? escape(s) : s;
+}
+
 //
 //--------------------------------------------------------------------
 
@@ -1454,6 +1476,8 @@ track_info_c::operator =(const track_info_c &src) {
   nalu_size_lengths          = src.nalu_size_lengths;
   nalu_size_length           = src.nalu_size_length;
 
+  attach_mode_list           = src.attach_mode_list;
+
   no_chapters                = src.no_chapters;
   no_attachments             = src.no_attachments;
   no_tags                    = src.no_tags;
