@@ -165,6 +165,12 @@ enum stereo_mode_e {
   STEREO_MODE_BOTH        =  3,
 };
 
+enum attach_mode_e {
+  ATTACH_MODE_SKIP,
+  ATTACH_MODE_TO_FIRST_FILE,
+  ATTACH_MODE_TO_ALL_FILES,
+};
+
 class track_info_c {
 protected:
   bool initialized;
@@ -234,6 +240,8 @@ public:
   map<int64_t, int> nalu_size_lengths;
   int nalu_size_length;
 
+  map<int64_t, attach_mode_e> attach_mode_list; // As given on the command line
+
   bool no_chapters, no_attachments, no_tags;
 
   // Some file formats can contain chapters, but for some the charset
@@ -315,6 +323,8 @@ public:
 
   virtual void flush_packetizers();
 
+  virtual attach_mode_e attachment_requested(int64_t id);
+
   virtual void display_identification_results();
 
 protected:
@@ -326,6 +336,8 @@ protected:
   virtual void id_result_track(int64_t track_id, const string &type, const string &info, const vector<string> &verbose_info);
   virtual void id_result_attachment(int64_t attachment_id, const string &type, int size, const string &file_name = empty_string, const string &description = empty_string);
 
+  virtual std::string id_escape_string(const std::string &s);
+
   static void id_result_container_unsupported(const string &filename, const string &info);
 };
 
