@@ -265,7 +265,8 @@ job_run_dialog::on_end_process(wxProcessEvent &evt) {
 
   jobs[ndx].finished_on = time(NULL);
 
-  add_to_log(wxString::Format(Z("Finished job ID %d on %s: status '%s'"), jobs[ndx].id, format_date_time(jobs[ndx].finished_on).c_str(), status));
+  wxString format = Z("Finished job ID %d on %s: status '%s'");
+  add_to_log(wxString::Format(format, jobs[ndx].id, format_date_time(jobs[ndx].finished_on).c_str(), status));
 
   mdlg->save_job_queue();
   delete process;
@@ -317,7 +318,7 @@ job_log_dialog::job_log_dialog(wxWindow *parent,
 
 void
 job_log_dialog::on_save(wxCommandEvent &evt) {
-  wxFileDialog dialog(NULL, Z("Choose an output file"), last_open_dir, wxEmptyString, wxString::Format(Z("Text files (*.txt)|*.txt|%s"), ALLFILES.c_str()), wxSAVE | wxOVERWRITE_PROMPT);
+  wxFileDialog dialog(NULL, Z("Choose an output file"), last_open_dir, wxEmptyString, wxString::Format(Z("Text files (*.txt)|*.txt|%s"), ALLFILES.c_str()), wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
   if(dialog.ShowModal() != wxID_OK)
     return;
 
@@ -377,28 +378,28 @@ job_dialog::job_dialog(wxWindow *parent):
   wxBoxSizer *siz_b_right = new wxBoxSizer(wxVERTICAL);
   b_up = new wxButton(this, ID_JOBS_B_UP, Z("&Up"));
   b_up->SetToolTip(TIP("Move the selected job(s) up"));
-  siz_b_right->Add(b_up, 0, wxLEFT | wxBOTTOM, 10);
+  siz_b_right->Add(b_up, 0, wxGROW | wxLEFT | wxBOTTOM, 10);
   b_down = new wxButton(this, ID_JOBS_B_DOWN, Z("&Down"));
   b_down->SetToolTip(TIP("Move the selected job(s) down"));
-  siz_b_right->Add(b_down, 0, wxLEFT | wxBOTTOM, 10);
+  siz_b_right->Add(b_down, 0, wxGROW | wxLEFT | wxBOTTOM, 10);
   siz_b_right->AddSpacer(15);
 
   b_reenable = new wxButton(this, ID_JOBS_B_REENABLE, Z("&Re-enable"));
   b_reenable->SetToolTip(TIP("Re-enable the selected job(s)"));
-  siz_b_right->Add(b_reenable, 0, wxLEFT | wxBOTTOM, 10);
+  siz_b_right->Add(b_reenable, 0, wxGROW | wxLEFT | wxBOTTOM, 10);
   b_disable = new wxButton(this, ID_JOBS_B_DISABLE, Z("&Disable"));
   b_disable->SetToolTip(TIP("Disable the selected job(s) and sets their status to 'done'"));
-  siz_b_right->Add(b_disable, 0, wxLEFT | wxBOTTOM, 10);
+  siz_b_right->Add(b_disable, 0, wxGROW | wxLEFT | wxBOTTOM, 10);
   siz_b_right->AddSpacer(15);
 
   b_delete = new wxButton(this, ID_JOBS_B_DELETE, Z("D&elete"));
   b_delete->SetToolTip(TIP("Delete the selected job(s) from the job queue"));
-  siz_b_right->Add(b_delete, 0, wxLEFT | wxBOTTOM, 10);
+  siz_b_right->Add(b_delete, 0, wxGROW | wxLEFT | wxBOTTOM, 10);
   siz_b_right->AddSpacer(15);
 
   b_view_log = new wxButton(this, ID_JOBS_B_VIEW_LOG, Z("&View log"));
   b_view_log->SetToolTip(TIP("View the output that mkvmerge generated during the muxing process for the selected job(s)"));
-  siz_b_right->Add(b_view_log, 0, wxLEFT, 10);
+  siz_b_right->Add(b_view_log, 0, wxGROW | wxLEFT, 10);
   siz_line->Add(siz_b_right, 0, 0, 0);
   siz_all->Add(siz_line, 1, wxGROW | wxLEFT | wxRIGHT, 10);
 
@@ -412,11 +413,11 @@ job_dialog::job_dialog(wxWindow *parent):
 
   b_start = new wxButton(this, ID_JOBS_B_START, Z("&Start"));
   b_start->SetToolTip(TIP("Start the jobs whose status is 'pending'"));
-  siz_b_bottom->Add(b_start, 0, wxRIGHT, 10);
+  siz_b_bottom->Add(b_start, 0, wxGROW | wxRIGHT, 10);
   siz_b_bottom->Add(10, 0, 0, 0, 0);
-  b_start_selected = new wxButton(this, ID_JOBS_B_START_SELECTED, Z("S&tart selected"), wxDefaultPosition, wxSize(100, -1));
+  b_start_selected = new wxButton(this, ID_JOBS_B_START_SELECTED, Z("S&tart selected"));
   b_start_selected->SetToolTip(TIP("Start the selected job(s) regardless of their status"));
-  siz_b_bottom->Add(b_start_selected, 0, wxLEFT, 10);
+  siz_b_bottom->Add(b_start_selected, 0, wxGROW | wxLEFT, 10);
   siz_all->Add(siz_b_bottom, 0, wxGROW | wxLEFT | wxRIGHT | wxBOTTOM, 10);
   siz_all->SetSizeHints(this);
   SetSizer(siz_all);
