@@ -48,14 +48,16 @@
 #include "tab_chapters.h"
 #include "tab_input.h"
 #include "tab_global.h"
+#include "translation.h"
 #include "xml_element_mapping.h"
+#include "wxcommon.h"
 
 mmg_app *app;
 mmg_dialog *mdlg;
 wxString last_open_dir;
 vector<wxString> last_settings;
 vector<wxString> last_chapters;
-vector<mmg_file_t> files;
+vector<mmg_file_cptr> files;
 vector<mmg_track_t *> tracks;
 map<wxString, wxString> capabilities;
 vector<job_t> jobs;
@@ -153,84 +155,65 @@ cli_options_dlg::cli_options_dlg(wxWindow *parent):
 
 void
 cli_options_dlg::init_cli_option_list() {
-  all_cli_options.push_back(cli_option_t(Z("### Global output control ###"),
-                                         Z("Several options that control the overall output that mkvmerge creates.")));
-  all_cli_options.push_back(cli_option_t(Z("--cluster-length"),
-                                         Z("This option needs an additional argument 'n'. Tells mkvmerge to put "
-                                           "at most 'n' data blocks into each cluster. If the number is"
-                                           "postfixed with 'ms' then put at most 'n' milliseconds of data into "
-                                           "each cluster. The maximum length for a cluster is 32767ms. Programs "
-                                           "will only be able to seek to clusters, so creating larger clusters "
-                                           "may lead to imprecise seeking and/or processing.")));
-  all_cli_options.push_back(cli_option_t(Z("--no-cues"),
-                                         Z("Tells mkvmerge not to create and write the cue data which can be "
-                                           "compared to an index in an AVI. Matroska files can be played back "
-                                           "without the cue data, but seeking will probably be imprecise and "
-                                           "slower. Use this only for testing purposes.")));
-  all_cli_options.push_back(cli_option_t(Z("--no-clusters-in-meta-seek"),
-                                         Z("Tells mkvmerge not to create a meta seek element at the end of the "
-                                           "file containing all clusters.")));
-  all_cli_options.push_back(cli_option_t(Z("--disable-lacing"),
-                                         Z("Disables lacing for all tracks. This will increase the file's size, "
-                                           "especially if there are many audio tracks. Use only for testing.")));
-  all_cli_options.push_back(cli_option_t(Z("--enable-durations"),
-                                         Z("Write durations for all blocks. This will increase file size and "
-                                           "does not offer any additional value for players at the moment.")));
-  all_cli_options.push_back(cli_option_t(Z("--timecode-scale REPLACEME"),
-                                         Z("Forces the timecode scale factor to REPLACEME. You have to replace "
-                                           "REPLACEME with a value between 1000 and 10000000 or with -1. "
-                                           "Normally mkvmerge "
-                                           "will use a value of 1000000 which means that timecodes and "
-                                           "durations will have a precision of 1ms. For files that will not "
-                                           "contain a video track but at least one audio track mkvmerge "
-                                           "will automatically choose a timecode scale factor so that all "
-                                           "timecodes and durations have a precision of one sample. This "
-                                           "causes bigger overhead but allows precise seeking and extraction. "
-                                           "If the magical value -1 is used then mkvmerge will use sample "
-                                           "precision even if a video track is present.")));
-  all_cli_options.push_back(cli_option_t(Z("### Development hacks ###"),
-                                         Z("Options meant ONLY for developpers. Do not use them. If something "
-                                           "is considered to be an officially supported option then it's NOT "
-                                           "in this list!")));
-  all_cli_options.push_back(cli_option_t(Z("--engage space_after_chapters"),
-                                         Z("Leave additional space (EbmlVoid) in the output file after the "
-                                           "chapters.")));
-  all_cli_options.push_back(cli_option_t(Z("--engage no_chapters_in_meta_seek"),
-                                         Z("Do not add an entry for the chapters in the meta seek element.")));
-  all_cli_options.push_back(cli_option_t(Z("--engage no_meta_seek"),
-                                         Z("Do not write meta seek elements at all.")));
-  all_cli_options.push_back(cli_option_t(Z("--engage lacing_xiph"),
-                                         Z("Force Xiph style lacing.")));
-  all_cli_options.push_back(cli_option_t(Z("--engage lacing_ebml"),
-                                         Z("Force EBML style lacing.")));
-  all_cli_options.push_back(cli_option_t(Z("--engage native_mpeg4"),
-                                         Z("Analyze MPEG4 bitstreams, put each frame into one Matroska block, "
-                                           "use proper timestamping (I P B B = 0 120 40 80), use "
-                                           "V_MPEG4/ISO/... CodecIDs.")));
-  all_cli_options.push_back(cli_option_t(Z("--engage no_variable_data"),
-                                         Z("Use fixed values for the elements that change with each file "
-                                           "otherwise (muxing date, segment UID, track UIDs etc.). Two files "
-                                           "muxed with the same settings and this switch activated will be "
-                                           "identical.")));
-  all_cli_options.push_back(cli_option_t(Z("--engage no_default_header_values"),
-                                         Z("Do not write those header elements whose values are the same "
-                                           "as their default values according to the Matroska specs.")));
-  all_cli_options.push_back(cli_option_t(Z("--engage force_passthrough_packetizer"),
-                                         Z("Forces the Matroska reader to use the generic passthrough "
-                                           "packetizer even for known and supported track types.")));
-  all_cli_options.push_back(cli_option_t(Z("--engage allow_avc_in_vfw_mode"),
-                                         Z("Allows storing AVC/h.264 video in Video-for-Windows compatibility "
-                                           "mode, e.g. when it is read from an AVI")));
-  all_cli_options.push_back(cli_option_t(Z("--engage use_simpleblock"),
-                                         Z("Enable use of SimpleBlock instead of BlockGroup when possible.")));
-  all_cli_options.push_back(cli_option_t(Z("--engage old_aac_codecid"),
-                                         Z("Use the old AAC codec IDs (e.g. 'A_AAC/MPEG4/SBR') instead of the "
-                                           "new one ('A_AAC').")));
-  all_cli_options.push_back(cli_option_t(Z("--engage use_codec_state"),
-                                         Z("Allows the use of the CodecState element. This is used for e.g. "
-                                           "MPEG-1/-2 video tracks for storing the sequence headers.")));
-  all_cli_options.push_back(cli_option_t(Z("--engage cow"),
-                                         Z("No help available.")));
+  all_cli_options.clear();
+  all_cli_options.push_back(cli_option_t(  Z("### Global output control ###"),
+                                           Z("Several options that control the overall output that mkvmerge creates.")));
+  all_cli_options.push_back(cli_option_t(wxU("--cluster-length"),
+                                           Z("This option needs an additional argument 'n'. Tells mkvmerge to put at most 'n' data blocks into each cluster. "
+                                             "If the number is postfixed with 'ms' then put at most 'n' milliseconds of data into each cluster. "
+                                             "The maximum length for a cluster is 32767ms. Programs will only be able to seek to clusters, so creating larger clusters "
+                                             "may lead to imprecise seeking and/or processing.")));
+  all_cli_options.push_back(cli_option_t(wxU("--no-cues"),
+                                           Z("Tells mkvmerge not to create and write the cue data which can be compared to an index in an AVI. "
+                                             "Matroska files can be played back without the cue data, but seeking will probably be imprecise and slower. "
+                                             "Use this only for testing purposes.")));
+  all_cli_options.push_back(cli_option_t(wxU("--no-clusters-in-meta-seek"),
+                                           Z("Tells mkvmerge not to create a meta seek element at the end of the file containing all clusters.")));
+  all_cli_options.push_back(cli_option_t(wxU("--disable-lacing"),
+                                           Z("Disables lacing for all tracks. This will increase the file's size, especially if there are many audio tracks. Use only for testing.")));
+  all_cli_options.push_back(cli_option_t(wxU("--enable-durations"),
+                                           Z("Write durations for all blocks. This will increase file size and does not offer any additional value for players at the moment.")));
+  all_cli_options.push_back(cli_option_t(  Z("--timecode-scale REPLACEME"),
+                                           Z("Forces the timecode scale factor to REPLACEME. You have to replace REPLACEME with a value between 1000 and 10000000 or with -1. "
+                                             "Normally mkvmerge will use a value of 1000000 which means that timecodes and durations will have a precision of 1ms. "
+                                             "For files that will not contain a video track but at least one audio track mkvmerge will automatically choose a timecode scale factor "
+                                             "so that all timecodes and durations have a precision of one sample. "
+                                             "This causes bigger overhead but allows precise seeking and extraction. "
+                                             "If the magical value -1 is used then mkvmerge will use sample precision even if a video track is present.")));
+  all_cli_options.push_back(cli_option_t(wxU("### Development hacks ###"),
+                                           Z("Options meant ONLY for developpers. Do not use them. If something is considered to be an officially supported option "
+                                             "then it's NOT in this list!")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage space_after_chapters"),
+                                           Z("Leave additional space (EbmlVoid) in the output file after the chapters.")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage no_chapters_in_meta_seek"),
+                                           Z("Do not add an entry for the chapters in the meta seek element.")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage no_meta_seek"),
+                                           Z("Do not write meta seek elements at all.")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage lacing_xiph"),
+                                           Z("Force Xiph style lacing.")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage lacing_ebml"),
+                                           Z("Force EBML style lacing.")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage native_mpeg4"),
+                                           Z("Analyze MPEG4 bitstreams, put each frame into one Matroska block, use proper timestamping (I P B B = 0 120 40 80), "
+                                             "use V_MPEG4/ISO/... CodecIDs.")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage no_variable_data"),
+                                           Z("Use fixed values for the elements that change with each file otherwise (muxing date, segment UID, track UIDs etc.). "
+                                             "Two files muxed with the same settings and this switch activated will be identical.")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage no_default_header_values"),
+                                           Z("Do not write those header elements whose values are the same "
+                                             "as their default values according to the Matroska specs.")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage force_passthrough_packetizer"),
+                                           Z("Forces the Matroska reader to use the generic passthrough packetizer even for known and supported track types.")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage allow_avc_in_vfw_mode"),
+                                           Z("Allows storing AVC/h.264 video in Video-for-Windows compatibility mode, e.g. when it is read from an AVI")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage use_simpleblock"),
+                                           Z("Enable use of SimpleBlock instead of BlockGroup when possible.")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage old_aac_codecid"),
+                                           Z("Use the old AAC codec IDs (e.g. 'A_AAC/MPEG4/SBR') instead of the new one ('A_AAC').")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage use_codec_state"),
+                                           Z("Allows the use of the CodecState element. This is used for e.g. MPEG-1/-2 video tracks for storing the sequence headers.")));
+  all_cli_options.push_back(cli_option_t(wxU("--engage cow"),
+                                           Z("No help available.")));
 }
 
 void
@@ -664,6 +647,22 @@ set_combobox_selection(wxComboBox *cb,
     }
 }
 
+#if defined(USE_WXBITMAPCOMBOBOX)
+void
+set_combobox_selection(wxBitmapComboBox *cb,
+                       const wxString wanted) {
+  int i, count;
+
+  cb->SetValue(wanted);
+  count = cb->GetCount();
+  for (i = 0; count > i; ++i)
+    if (cb->GetString(i) == wanted) {
+      cb->SetSelection(i);
+      break;
+    }
+}
+#endif  // USE_WXBITMAPCOMBOBOX
+
 void
 wxdie(const wxString &errmsg) {
   wxMessageBox(errmsg, wxT("A serious error has occured"),
@@ -780,27 +779,23 @@ mmg_dialog::mmg_dialog():
 
   wxBoxSizer *bs_buttons = new wxBoxSizer(wxHORIZONTAL);
 
-  b_start_muxing =
-    new wxButton(panel, ID_B_STARTMUXING, Z("Sta&rt muxing"), wxDefaultPosition, wxSize(130, -1));
+  b_start_muxing = new wxButton(panel, ID_B_STARTMUXING, Z("Sta&rt muxing"));
   bs_buttons->Add(b_start_muxing, 0, wxALIGN_CENTER_HORIZONTAL | wxALL, 8);
 
-  b_copy_to_clipboard =
-    new wxButton(panel, ID_B_COPYTOCLIPBOARD, Z("&Copy to clipboard"), wxDefaultPosition, wxSize(130, -1));
-  bs_buttons->Add(10, 0);
+  b_copy_to_clipboard = new wxButton(panel, ID_B_COPYTOCLIPBOARD, Z("&Copy to clipboard"));
   bs_buttons->Add(b_copy_to_clipboard, 0, wxALIGN_CENTER_HORIZONTAL | wxALL, 8);
 
-  b_add_to_jobqueue =
-    new wxButton(panel, ID_B_ADD_TO_JOBQUEUE, Z("&Add to job queue"), wxDefaultPosition, wxSize(130, -1));
+  b_add_to_jobqueue = new wxButton(panel, ID_B_ADD_TO_JOBQUEUE, Z("&Add to job queue"));
   bs_buttons->Add(b_add_to_jobqueue, 0, wxALIGN_CENTER_HORIZONTAL | wxALL, 8);
 
   bs_main->Add(bs_buttons, 0, wxALIGN_CENTER_HORIZONTAL);
 
 #ifdef SYS_WINDOWS
-  SetSizeHints(600, 680);
-  SetSize(600, 680);
+  SetSizeHints(700, 680);
+  SetSize(700, 680);
 #else
-  SetSizeHints(600, 660);
-  SetSize(600, 660);
+  SetSizeHints(700, 660);
+  SetSize(700, 660);
 #endif
 
   load_preferences();
@@ -854,7 +849,7 @@ mmg_dialog::on_browse_output(wxCommandEvent &evt) {
   wxFileDialog dlg(NULL, Z("Choose an output file"), last_open_dir,
                    tc_output->GetValue().AfterLast(PSEP),
                    wxString::Format(Z("Matroska A/V files (*.mka;*.mkv)|*.mkv;*.mka|%s"), ALLFILES.c_str()),
-                   wxSAVE | wxOVERWRITE_PROMPT);
+                   wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
   if(dlg.ShowModal() != wxID_OK)
     return;
 
@@ -901,7 +896,7 @@ mmg_dialog::on_file_new(wxCommandEvent &evt) {
 
 void
 mmg_dialog::on_file_load(wxCommandEvent &evt) {
-  wxFileDialog dlg(NULL, Z("Choose an input file"), last_open_dir, wxEmptyString, wxString::Format(Z("mkvmerge GUI settings (*.mmg)|*.mmg|%s"), ALLFILES.c_str()), wxOPEN);
+  wxFileDialog dlg(NULL, Z("Choose an input file"), last_open_dir, wxEmptyString, wxString::Format(Z("mkvmerge GUI settings (*.mmg)|*.mmg|%s"), ALLFILES.c_str()), wxFD_OPEN);
   if(dlg.ShowModal() != wxID_OK)
     return;
 
@@ -922,8 +917,7 @@ mmg_dialog::load(wxString file_name,
 
   wxFileConfig cfg(wxT("mkvmerge GUI"), wxT("Moritz Bunkus"), file_name);
   cfg.SetPath(wxT("/mkvmergeGUI"));
-  if (!cfg.Read(wxT("file_version"), &version) || (1 > version) ||
-      (MMG_CONFIG_FILE_VERSION_MAX < version)) {
+  if (!cfg.Read(wxT("file_version"), &version) || (1 > version) || (MMG_CONFIG_FILE_VERSION_MAX < version)) {
     if (used_for_jobs)
       return;
     wxMessageBox(Z("The file does not seem to be a valid mkvmerge GUI settings file."), Z("Error loading settings"), wxOK | wxCENTER | wxICON_ERROR);
@@ -946,7 +940,7 @@ mmg_dialog::load(wxString file_name,
 
 void
 mmg_dialog::on_file_save(wxCommandEvent &evt) {
-  wxFileDialog dlg(NULL, Z("Choose an output file"), last_open_dir, wxEmptyString, wxString::Format(Z("mkvmerge GUI settings (*.mmg)|*.mmg|%s"), ALLFILES.c_str()), wxSAVE | wxOVERWRITE_PROMPT);
+  wxFileDialog dlg(NULL, Z("Choose an output file"), last_open_dir, wxEmptyString, wxString::Format(Z("mkvmerge GUI settings (*.mmg)|*.mmg|%s"), ALLFILES.c_str()), wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
   if(dlg.ShowModal() != wxID_OK)
     return;
 
@@ -1064,7 +1058,7 @@ mmg_dialog::check_before_overwriting() {
         (test_name.GetExt() == ext)) {
       if (file_name.HasExt())
         ext = wxU(".") + ext;
-      if (wxMessageBox(wxString::Format(Z("Splitting is active, and at least one of the potential output files '%s%s*%s%s' already exists. Do you want to overwrite them?"),
+      if (wxMessageBox(wxString::Format(Z("Splitting is active, and at least one of the potential output files '%s%s*%s' already exists. Do you want to overwrite them?"),
                                         dir.c_str(), name.c_str(), ext.c_str()),
                        Z("Overwrite existing file(s)?"), wxYES_NO) != wxYES)
         return false;
@@ -1131,7 +1125,7 @@ mmg_dialog::muxing_has_finished() {
 void
 mmg_dialog::on_help(wxCommandEvent &evt) {
   if (help == NULL) {
-    wxDirDialog dlg(this, Z("Chosoe the location of the mkvmerge GUI help files"));
+    wxDirDialog dlg(this, Z("Choose the location of the mkvmerge GUI help files"));
     vector<wxString> potential_help_paths;
     vector<wxString>::const_iterator php;
     wxString help_path;
@@ -1239,7 +1233,7 @@ void
 mmg_dialog::on_save_cmdline(wxCommandEvent &evt) {
   wxFile *file;
   wxString s;
-  wxFileDialog dlg(NULL, Z("Choose an output file"), last_open_dir, wxEmptyString, ALLFILES, wxSAVE | wxOVERWRITE_PROMPT);
+  wxFileDialog dlg(NULL, Z("Choose an output file"), last_open_dir, wxEmptyString, ALLFILES, wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
   if(dlg.ShowModal() == wxID_OK) {
     update_command_line();
 
@@ -1260,7 +1254,7 @@ mmg_dialog::on_create_optionfile(wxCommandEvent &evt) {
   string arg_utf8;
   wxFile *file;
 
-  wxFileDialog dlg(NULL, Z("Choose an output file"), last_open_dir, wxEmptyString, ALLFILES, wxSAVE | wxOVERWRITE_PROMPT);
+  wxFileDialog dlg(NULL, Z("Choose an output file"), last_open_dir, wxEmptyString, ALLFILES, wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
   if(dlg.ShowModal() == wxID_OK) {
     update_command_line();
 
@@ -1313,17 +1307,10 @@ mmg_dialog::on_update_command_line(wxTimerEvent &evt) {
 
 void
 mmg_dialog::update_command_line() {
-  uint32_t fidx, tidx, i, args_start;
-  bool tracks_selected_here;
-  bool no_audio, no_video, no_subs;
-  mmg_file_t *f;
-  mmg_attachment_t *a;
-  wxString sid, old_cmdline, arg, aids, sids, dids, track_order;
-  wxString append_mapping;
-  vector<wxString> opts;
+  unsigned int i;
 
-  old_cmdline = cmdline;
-  cmdline = wxT("\"") + options.mkvmerge + wxT("\" -o \"") + tc_output->GetValue() + wxT("\" ");
+  wxString old_cmdline = cmdline;
+  cmdline              = wxT("\"") + options.mkvmerge + wxT("\" -o \"") + tc_output->GetValue() + wxT("\" ");
 
   clargs.Clear();
   clargs.Add(options.mkvmerge);
@@ -1331,29 +1318,40 @@ mmg_dialog::update_command_line() {
   clargs.Add(wxT("UTF-8"));
   clargs.Add(wxT("-o"));
   clargs.Add(tc_output->GetValue());
-  args_start = clargs.Count();
+
+#if defined(HAVE_LIBINTL_H)
+  if (!app->m_ui_locale.empty()) {
+    clargs.Add(wxT("--ui-language"));
+    clargs.Add(wxCS2WS(app->m_ui_locale));
+  }
+#endif  // HAVE_LIBINTL_H
+
+  unsigned int args_start = clargs.Count();
 
   if (options.priority != wxT("normal")) {
     clargs.Add(wxT("--priority"));
     clargs.Add(options.priority);
   }
 
-  for (fidx = 0; fidx < files.size(); fidx++) {
-    f = &files[fidx];
-    tracks_selected_here = false;
-    no_audio = true;
-    no_video = true;
-    no_subs = true;
-    aids = wxEmptyString;
-    sids = wxEmptyString;
-    dids = wxEmptyString;
-    for (tidx = 0; tidx < f->tracks.size(); tidx++) {
-      mmg_track_ptr &t = f->tracks[tidx];
+  unsigned int fidx;
+  for (fidx = 0; files.size() > fidx; fidx++) {
+    mmg_file_cptr &f          = files[fidx];
+    bool tracks_selected_here = false;
+    bool no_audio             = true;
+    bool no_video             = true;
+    bool no_subs              = true;
+    wxString aids             = wxEmptyString;
+    wxString sids             = wxEmptyString;
+    wxString dids             = wxEmptyString;
+
+    unsigned int tidx;
+    for (tidx = 0; f->tracks.size() > tidx; tidx++) {
+      mmg_track_cptr &t = f->tracks[tidx];
       if (!t->enabled)
         continue;
 
       tracks_selected_here = true;
-      sid = wxLongLong(t->id).ToString();
+      wxString sid         = wxLongLong(t->id).ToString();
 
       if (t->type == wxT('a')) {
         no_audio = false;
@@ -1378,7 +1376,7 @@ mmg_dialog::update_command_line() {
           sids += wxT(",");
         sids += sid;
 
-        if ((t->sub_charset.Length() > 0) && (t->sub_charset != Z("default"))) {
+        if ((t->sub_charset.Length() > 0) && (t->sub_charset != wxT("default"))) {
           clargs.Add(wxT("--sub-charset"));
           clargs.Add(sid + wxT(":") + shell_escape(t->sub_charset));
         }
@@ -1389,18 +1387,18 @@ mmg_dialog::update_command_line() {
         clargs.Add(sid + wxT(":") + extract_language_code(t->language));
       }
 
-      if (!t->appending && (t->cues != Z("default"))) {
+      if (!t->appending && (t->cues != wxT("default"))) {
         clargs.Add(wxT("--cues"));
-        if (t->cues == Z("only for I frames"))
+        if (t->cues == wxT("only for I frames"))
           clargs.Add(sid + wxT(":iframes"));
-        else if (t->cues == Z("for all frames"))
+        else if (t->cues == wxT("for all frames"))
           clargs.Add(sid + wxT(":all"));
-        else if (t->cues == Z("none"))
+        else if (t->cues == wxT("none"))
           clargs.Add(sid + wxT(":none"));
       }
 
       if ((t->delay.Length() > 0) || (t->stretch.Length() > 0)) {
-        arg = sid + wxT(":");
+        wxString arg = sid + wxT(":");
         if (t->delay.Length() > 0)
           arg += t->delay;
         else
@@ -1460,7 +1458,7 @@ mmg_dialog::update_command_line() {
 
       if (!t->appending && (t->compression.Length() > 0)) {
         wxString compression = t->compression;
-        if (compression == Z("none"))
+        if (compression == wxT("none"))
           compression = wxT("none");
         clargs.Add(wxT("--compression"));
         clargs.Add(sid + wxT(":") + compression);
@@ -1472,8 +1470,8 @@ mmg_dialog::update_command_line() {
       }
 
       if (t->user_defined.Length() > 0) {
-        opts = split(t->user_defined, wxString(wxT(" ")));
-        for (i = 0; i < opts.size(); i++) {
+        vector<wxString> opts = split(t->user_defined, wxString(wxT(" ")));
+        for (i = 0; opts.size() > i; i++) {
           wxString opt = strip(opts[i]);
           opt.Replace(wxT("<TID>"), sid, true);
           clargs.Add(opt);
@@ -1497,8 +1495,27 @@ mmg_dialog::update_command_line() {
     if (tracks_selected_here) {
       if (f->no_chapters)
         clargs.Add(wxT("--no-chapters"));
+
       if (f->no_attachments)
         clargs.Add(wxT("--no-attachments"));
+      else {
+        std::vector<mmg_attached_file_cptr>::iterator att_file = f->attached_files.begin();
+        std::vector<wxString> att_file_ids;
+
+        while (att_file != f->attached_files.end()) {
+          if ((*att_file)->enabled)
+            att_file_ids.push_back(wxString::Format(wxT("%ld"), (*att_file)->id));
+          ++att_file;
+        }
+
+        if (!att_file_ids.empty()) {
+          clargs.Add(wxT("--attachments"));
+          clargs.Add(join(wxT(","), att_file_ids));
+
+        } else if (!f->attached_files.empty())
+          clargs.Add(wxT("--no-attachments"));
+      }
+
       if (f->no_tags)
         clargs.Add(wxT("--no-tags"));
 
@@ -1516,20 +1533,20 @@ mmg_dialog::update_command_line() {
     }
   }
 
-  track_order = create_track_order(false);
+  wxString track_order = create_track_order(false);
   if (track_order.length() > 0) {
     clargs.Add(wxT("--track-order"));
     clargs.Add(track_order);
   }
 
-  append_mapping = create_append_mapping();
+  wxString append_mapping = create_append_mapping();
   if (append_mapping.length() > 0) {
     clargs.Add(wxT("--append-to"));
     clargs.Add(append_mapping);
   }
 
-  for (fidx = 0; fidx < attachments.size(); fidx++) {
-    a = &attachments[fidx];
+  for (fidx = 0; attachments.size() > fidx; fidx++) {
+    mmg_attachment_cptr &a = attachments[fidx];
 
     clargs.Add(wxT("--attachment-mime-type"));
     clargs.Add(a->mime_type);
@@ -1606,7 +1623,7 @@ mmg_dialog::update_command_line() {
 
   cli_options = strip(cli_options);
   if (cli_options.length() > 0) {
-    opts = split(cli_options, wxString(wxT(" ")));
+    vector<wxString> opts = split(cli_options, wxString(wxT(" ")));
     for (i = 0; i < opts.size(); i++)
       clargs.Add(strip(opts[i]));
   }
@@ -2182,6 +2199,31 @@ BEGIN_EVENT_TABLE(mmg_dialog, wxFrame)
   EVT_CLOSE(mmg_dialog::on_close)
 END_EVENT_TABLE();
 
+void
+mmg_app::init_ui_locale(wxConfigBase *cfg) {
+  std::string locale;
+
+#if defined(HAVE_LIBINTL_H)
+  wxString w_locale;
+
+  translation_c::initialize_available_translations();
+
+  cfg->SetPath(wxT("/GUI"));
+  if (cfg->Read(wxT("ui_locale"), &w_locale)) {
+    locale = wxMB(w_locale);
+    if (-1 == translation_c::look_up_translation(locale))
+      locale = "";
+  }
+
+  if (locale.empty())
+    locale = translation_c::get_default_ui_locale();
+
+  m_ui_locale = locale;
+#endif  // HAVE_LIBINTL_H
+
+  init_locales(locale);
+}
+
 bool
 mmg_app::OnInit() {
   wxConfigBase *cfg;
@@ -2189,13 +2231,15 @@ mmg_app::OnInit() {
   wxString k, v;
   int index;
 
+  cfg = new wxConfig(wxT("mkvmergeGUI"));
+  wxConfigBase::Set(cfg);
+
   init_stdio();
+  init_ui_locale(cfg);
   mm_file_io_c::setup();
   cc_local_utf8 = utf8_init("");
   xml_element_map_init();
 
-  cfg = new wxConfig(wxT("mkvmergeGUI"));
-  wxConfigBase::Set(cfg);
   cfg->SetPath(wxT("/GUI"));
   cfg->Read(wxT("last_directory"), &last_open_dir, wxEmptyString);
   for (i = 0; i < 4; i++) {
@@ -2235,8 +2279,8 @@ mmg_app::OnExit() {
   cfg->SetPath(wxT("/GUI"));
   cfg->Write(wxT("last_directory"), last_open_dir);
   cfg->SetPath(wxT("/chapter_editor"));
-  cfg->Write(wxT("default_language"), wxCS2WS(default_chapter_language));
-  cfg->Write(wxT("default_country"), wxCS2WS(default_chapter_country));
+  cfg->Write(wxT("default_language"), wxString(default_chapter_language.c_str(), wxConvUTF8));
+  cfg->Write(wxT("default_country"), wxString(default_chapter_country.c_str(), wxConvUTF8));
   cfg->Flush();
 
   delete cfg;
