@@ -19,14 +19,16 @@
 
 #include "os.h"
 
-#include "wx/string.h"
 #include "wx/app.h"
 #include "wx/combobox.h"
+#include "wx/config.h"
+#include "wx/string.h"
 
 #include "ebml/EbmlUnicodeString.h"
 
 #include "iso639.h"
 #include "smart_pointers.h"
+#include "translation_table.h"
 #include "wxcommon.h"
 
 #ifdef SYS_WINDOWS
@@ -43,7 +45,17 @@
 # define LEFTRIGHTSPACING 5
 #endif
 
-#define MMG_CONFIG_FILE_VERSION_MAX 2
+// Config file versions and their differences
+//
+// Version 1: base settings
+// Version 2: Added in v1.5.0:
+//   Added splitting by timecodes. The old boolean "split_by_size" was
+//   replaced by new string "split_mode".
+// Version 3: Added after v2.4.2:
+//   The per-file boolean "no attachments" was removed and replaced by
+//   the handling of individual attached files.
+
+#define MMG_CONFIG_FILE_VERSION_MAX 3
 
 using namespace std;
 using namespace libebml;
@@ -79,13 +91,31 @@ struct mmg_track_t {
     stereo_mode(0),
     appending(false) {};
 };
-typedef counted_ptr<mmg_track_t> mmg_track_ptr;
+typedef counted_ptr<mmg_track_t> mmg_track_cptr;
+
+struct mmg_file_t;
+
+struct mmg_attached_file_t {
+  bool enabled;
+  wxString name, description, mime_type;
+  long id, size;
+  mmg_file_t *source;
+
+  mmg_attached_file_t()
+    : enabled(true)
+    , id(0)
+    , size(0)
+    , source(NULL)
+  { };
+};
+typedef counted_ptr<mmg_attached_file_t> mmg_attached_file_cptr;
 
 struct mmg_file_t {
   wxString file_name, title;
   bool title_was_present;
   int container;
-  vector<mmg_track_ptr> tracks;
+  vector<mmg_track_cptr> tracks;
+  vector<mmg_attached_file_cptr> attached_files;
   bool no_chapters, no_attachments, no_tags;
   bool appending;
 
@@ -94,7 +124,7 @@ struct mmg_file_t {
     no_chapters(false), no_attachments(false), no_tags(false),
     appending(false) {};
 };
-typedef counted_ptr<mmg_file_t> mmg_file_ptr;
+typedef counted_ptr<mmg_file_t> mmg_file_cptr;
 
 struct mmg_attachment_t {
   wxString file_name, stored_name, description, mime_type;
@@ -103,7 +133,7 @@ struct mmg_attachment_t {
   mmg_attachment_t():
     style(0) {};
 };
-typedef counted_ptr<mmg_attachment_t> mmg_attachment_ptr;
+typedef counted_ptr<mmg_attachment_t> mmg_attachment_cptr;
 
 typedef enum {
   ODM_FROM_FIRST_INPUT_FILE = 0,
@@ -139,9 +169,10 @@ struct mmg_options_t {
 extern wxString last_open_dir;
 extern vector<wxString> last_settings;
 extern vector<wxString> last_chapters;
-extern vector<mmg_file_t> files;
+extern vector<mmg_file_cptr> files;
 extern vector<mmg_track_t *> tracks;
-extern vector<mmg_attachment_t> attachments;
+extern vector<mmg_attachment_cptr> attachments;
+extern vector<mmg_attached_file_cptr> attached_files;
 extern wxArrayString sorted_charsets;
 extern wxArrayString sorted_iso_codes;
 extern bool title_was_present;
@@ -167,20 +198,26 @@ wxString create_track_order(bool all);
 int default_track_checked(char type);
 
 void set_combobox_selection(wxComboBox *cb, const wxString wanted);
+#if defined(USE_WXBITMAPCOMBOBOX)
+void set_combobox_selection(wxBitmapComboBox *cb, const wxString wanted);
+#endif  // USE_WXBITMAPCOMBOBOX
 
 void wxdie(const wxString &errmsg);
 
 #if defined(SYS_WINDOWS)
-#define TIP(s) format_tooltip(wxU(s))
+#define TIP(s) format_tooltip(Z(s))
 wxString format_tooltip(const wxString &s);
 #else
-#define TIP(s) wxU(s)
+#define TIP(s) Z(s)
 #endif
 
 class mmg_app: public wxApp {
+public:
+  std::string m_ui_locale;
 public:
   virtual bool OnInit();
   virtual int OnExit();
+  virtual void init_ui_locale(wxConfigBase *cfg);
 };
 
 extern mmg_app *app;
