@@ -11,6 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
+#include "os.h"
+
 #include "wx/wxprec.h"
 
 #include "wx/wx.h"
@@ -24,8 +26,28 @@
 #include "mmg.h"
 #include "mmg_dialog.h"
 #include "options_dialog.h"
+#include "translation.h"
+#include "wxcommon.h"
 
-std::vector<wxString> options_dialog::ms_priorities;
+#include <algorithm>
+#include <string>
+#include <vector>
+
+struct locale_sorter_t {
+  wxString display_val;
+  std::string locale;
+
+  locale_sorter_t(const wxString &n_display_val,
+                  const std::string &n_locale)
+    : display_val(n_display_val)
+    , locale(n_locale)
+  {
+  };
+
+  bool operator <(const locale_sorter_t &cmp) const {
+    return display_val < cmp.display_val;
+  };
+};
 
 options_dialog::options_dialog(wxWindow *parent,
                                mmg_options_t &options)
@@ -36,14 +58,14 @@ options_dialog::options_dialog(wxWindow *parent,
   wxStaticText *st_priority, *st_mkvmerge;
   wxButton *b_browse;
 
-  if (ms_priorities.empty()) {
+  if (cob_priority_translations.entries.empty()) {
 #ifdef SYS_WINDOWS
-    ms_priorities.push_back(wxT("highest"));
-    ms_priorities.push_back(wxT("higher"));
+    cob_priority_translations.add(wxT("highest"), Z("highest"));
+    cob_priority_translations.add(wxT("higher"),  Z("higher"));
 #endif
-    ms_priorities.push_back(wxT("normal"));
-    ms_priorities.push_back(wxT("lower"));
-    ms_priorities.push_back(wxT("lowest"));
+    cob_priority_translations.add(wxT("normal"),  Z("normal"));
+    cob_priority_translations.add(wxT("lower"),   Z("lower"));
+    cob_priority_translations.add(wxT("lowest"),  Z("lowest"));
   }
 
   // Create the controls.
@@ -55,17 +77,13 @@ options_dialog::options_dialog(wxWindow *parent,
   b_browse     = new wxButton(this, ID_B_BROWSEMKVMERGE, Z("Browse"));
 
   st_priority  = new wxStaticText(this, -1, Z("Process priority:"));
-  cob_priority = new wxComboBox(this, ID_COB_PRIORITY, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
+  cob_priority = new wxMTX_COMBOBOX_TYPE(this, ID_COB_PRIORITY, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
 
   cob_priority->SetToolTip(TIP("Sets the priority that mkvmerge will run with."));
 
-#if defined(SYS_WINDOWS)
-  cob_priority->Append(Z("highest"));
-  cob_priority->Append(Z("higher"));
-#endif
-  cob_priority->Append(Z("normal"));
-  cob_priority->Append(Z("lower"));
-  cob_priority->Append(Z("lowest"));
+  int i;
+  for (i = 0; cob_priority_translations.entries.size() > i; ++i)
+    cob_priority->Append(cob_priority_translations.entries[i].translated);
 
   cb_always_use_simpleblock = new wxCheckBox(this, ID_CB_ALWAYS_USE_SIMPLEBLOCK, Z("Always use simple blocks"));
   cb_always_use_simpleblock->SetToolTip(TIP("Always adds '--engage use_simpleblock' to the command line. "
@@ -117,6 +135,38 @@ options_dialog::options_dialog(wxWindow *parent,
   cb_gui_debugging->SetToolTip(TIP("Shows mmg's debug window in which debug messages will appear. "
                                    "This is only useful if you're helping the author debug a problem in mmg."));
 
+#if defined(HAVE_LIBINTL_H)
+  wxStaticText *st_ui_language = new wxStaticText(this, -1, Z("Interface language:"));
+  cob_ui_language = new wxMTX_COMBOBOX_TYPE(this, ID_COB_UI_LANGUAGE,  wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
+
+  std::string ui_locale_lower = downcase(app->m_ui_locale);
+  std::vector<translation_c>::iterator translation = translation_c::ms_available_translations.begin();
+  wxString select_locale;
+  std::vector<locale_sorter_t> sorted_entries;
+  while (translation != translation_c::ms_available_translations.end()) {
+    wxString curr_entry = wxCS2WS((boost::format("%1% (%2%)") % translation->m_translated_name % translation->m_english_name).str());
+    sorted_entries.push_back(locale_sorter_t(curr_entry, translation->get_locale()));
+
+    if (   (select_locale.IsEmpty() && (translation->m_english_name == "English"))
+        || (ui_locale_lower == downcase(translation->get_locale())))
+      select_locale = curr_entry;
+
+    ++translation;
+  }
+
+  wxLogMessage(wxT("Locale selection logic: select_locale %s uu_locale_lower %s translation_c::get_default_ui_locale() %s app->m_ui_locale %s"),
+               select_locale.c_str(), wxCS2WS(ui_locale_lower), wxCS2WS(translation_c::get_default_ui_locale()), wxCS2WS(app->m_ui_locale));
+
+  std::sort(sorted_entries.begin(), sorted_entries.end());
+
+  std::vector<locale_sorter_t>::iterator locale_entry = sorted_entries.begin();
+  while (locale_entry != sorted_entries.end()) {
+    cob_ui_language->Append(locale_entry->display_val);
+    m_sorted_locales.push_back(locale_entry->locale);
+    ++locale_entry;
+  }
+#endif  // HAVE_LIBINTL_H
+
   // Set the defaults.
 
   cb_autoset_output_filename->SetValue(m_options.autoset_output_filename);
@@ -133,6 +183,10 @@ options_dialog::options_dialog(wxWindow *parent,
   rb_odm_previous->SetValue(m_options.output_directory_mode == ODM_PREVIOUS);
   rb_odm_fixed->SetValue(m_options.output_directory_mode == ODM_FIXED);
 
+#if defined(HAVE_LIBINTL_H)
+  set_combobox_selection(cob_ui_language, select_locale);
+#endif  // HAVE_LIBINTL_H
+
   enable_output_filename_controls(m_options.autoset_output_filename);
 
   // Create the layout.
@@ -169,6 +223,15 @@ options_dialog::options_dialog(wxWindow *parent,
   siz_sb = new wxStaticBoxSizer(sb_mmg, wxVERTICAL);
   siz_sb->AddSpacer(5);
 
+#if defined(HAVE_LIBINTL_H)
+  siz_line = new wxBoxSizer(wxHORIZONTAL);
+  siz_line->Add(st_ui_language, 0, wxALIGN_CENTER_VERTICAL);
+  siz_line->Add(cob_ui_language, 0, wxALIGN_CENTER_VERTICAL | wxLEFT, 5);
+
+  siz_sb->Add(siz_line, 0, wxGROW | wxLEFT, 5);
+  siz_sb->AddSpacer(5);
+#endif  // HAVE_LIBINTL_H
+
   siz_sb->Add(cb_autoset_output_filename, 0, wxLEFT, 5);
   siz_sb->AddSpacer(5);
 
@@ -239,7 +302,7 @@ options_dialog::on_browse_mkvmerge(wxCommandEvent &evt) {
 #else
                    wxT("All files (*)|*"),
 #endif
-                   wxOPEN);
+                   wxFD_OPEN);
 
   if (dlg.ShowModal() != wxID_OK)
     return;
@@ -295,24 +358,30 @@ options_dialog::on_ok(wxCommandEvent &evt) {
                                             rb_odm_previous->GetValue()   ? ODM_PREVIOUS :
                                                                             ODM_FIXED;
 
+#if defined(HAVE_LIBINTL_H)
+  std::string new_ui_locale = m_sorted_locales[cob_ui_language->GetSelection()];
+
+  if (downcase(new_ui_locale) != downcase(app->m_ui_locale))
+    wxMessageBox(Z("Changing the interface language requires a restart to take effect."), Z("Restart required"), wxOK | wxCENTER | wxICON_INFORMATION);
+
+  app->m_ui_locale  = new_ui_locale;
+
+  wxConfigBase *cfg = wxConfigBase::Get();
+  cfg->SetPath(wxT("/GUI"));
+  cfg->Write(wxT("ui_locale"), wxString(new_ui_locale.c_str(), wxConvUTF8));
+#endif  // HAVE_LIBINTL_H
+
   EndModal(wxID_OK);
 }
 
 void
 options_dialog::select_priority(const wxString &priority) {
-  int i;
-
-  for (i = 0; ms_priorities.size() > i; ++i)
-    if (priority == ms_priorities[i]) {
-      if (cob_priority->GetCount() > i)
-        cob_priority->SetValue(cob_priority->GetString(i));
-      return;
-    }
+  cob_priority->SetValue(cob_priority_translations.to_translated(priority));
 }
 
 wxString
 options_dialog::get_selected_priority() {
-  return ms_priorities[cob_priority->GetSelection()];
+  return cob_priority_translations.to_english(cob_priority->GetValue());
 }
 
 IMPLEMENT_CLASS(options_dialog, wxDialog);
