@@ -11,6 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
+#include "os.h"
+
 #include <errno.h>
 #include <stdio.h>
 
@@ -32,15 +34,12 @@
 #include "mmg_dialog.h"
 #include "kax_analyzer.h"
 #include "tab_chapters.h"
+#include "wxcommon.h"
 
 using namespace std;
 using namespace libebml;
 using namespace libmatroska;
 
-#if ! wxCHECK_VERSION(2,4,2)
-# define wxTreeItemIdValue long
-#endif
-
 class chapters_drop_target_c: public wxFileDropTarget {
 private:
   tab_chapters *owner;
@@ -78,7 +77,7 @@ class chapter_values_dlg: public wxDialog {
   DECLARE_CLASS(chapter_values_dlg);
   DECLARE_EVENT_TABLE();
 public:
-  wxComboBox *cob_language, *cob_country;
+  wxMTX_COMBOBOX_TYPE *cob_language, *cob_country;
   wxCheckBox *cb_language, *cb_country;
 
 public:
@@ -112,11 +111,11 @@ chapter_values_dlg::chapter_values_dlg(wxWindow *parent,
     siz_input->AddGrowableCol(1);
 
     siz_input->Add(new wxStaticText(this, wxID_STATIC, Z("Language:")), 0, wxALIGN_CENTER_VERTICAL | wxRIGHT, 10);
-    cob_language = new wxComboBox(this, wxID_STATIC, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
+    cob_language = new wxMTX_COMBOBOX_TYPE(this, wxID_STATIC, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
     siz_input->Add(cob_language, 0, wxGROW, 0);
 
     siz_input->Add(new wxStaticText(this, wxID_STATIC, Z("Country:")), 0, wxALIGN_CENTER_VERTICAL | wxRIGHT, 10);
-    cob_country = new wxComboBox(this, wxID_STATIC, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
+    cob_country = new wxMTX_COMBOBOX_TYPE(this, wxID_STATIC, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
     siz_input->Add(cob_country, 0, wxGROW, 0);
 
   } else {
@@ -133,14 +132,14 @@ chapter_values_dlg::chapter_values_dlg(wxWindow *parent,
     cb_language = new wxCheckBox(this, ID_CVD_CB_LANGUAGE, Z("Set language to:"));
     cb_language->SetValue(false);
     siz_input->Add(cb_language, 0, wxALIGN_CENTER_VERTICAL | wxRIGHT, 10);
-    cob_language = new wxComboBox(this, wxID_STATIC, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
+    cob_language = new wxMTX_COMBOBOX_TYPE(this, wxID_STATIC, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
     cob_language->Enable(false);
     siz_input->Add(cob_language, 0, wxGROW, 0);
 
     cb_country = new wxCheckBox(this, ID_CVD_CB_COUNTRY, Z("Set country to:"));
     cb_country->SetValue(false);
     siz_input->Add(cb_country, 0, wxALIGN_CENTER_VERTICAL | wxRIGHT, 10);
-    cob_country = new wxComboBox(this, wxID_STATIC, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
+    cob_country = new wxMTX_COMBOBOX_TYPE(this, wxID_STATIC, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
     cob_country->Enable(false);
     siz_input->Add(cob_country, 0, wxGROW, 0);
 
@@ -150,10 +149,13 @@ chapter_values_dlg::chapter_values_dlg(wxWindow *parent,
   siz_all->Add(siz_input, 0, wxGROW | wxLEFT | wxRIGHT, 10);
   siz_all->AddSpacer(10);
 
+  bool found = false;
   for (i = 0; i < sorted_iso_codes.Count(); i++) {
     cob_language->Append(sorted_iso_codes[i]);
-    if (extract_language_code(sorted_iso_codes[i]) == old_def_language)
+    if (!found && (extract_language_code(sorted_iso_codes[i]) == old_def_language)) {
       cob_language->SetValue(sorted_iso_codes[i]);
+      found = true;
+    }
   }
 
   cob_country->Append(wxEmptyString);
@@ -227,17 +229,17 @@ tab_chapters::tab_chapters(wxWindow *parent,
   tc_chapters = new wxTreeCtrl(this, ID_TRC_CHAPTERS, wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER | wxTR_HAS_BUTTONS);
 #endif
 
-  b_add_chapter = new wxButton(this, ID_B_ADDCHAPTER, Z("Add chapter"), wxDefaultPosition, wxSize(120, -1));
+  b_add_chapter = new wxButton(this, ID_B_ADDCHAPTER, Z("Add chapter"));
 
-  b_add_subchapter = new wxButton(this, ID_B_ADDSUBCHAPTER, Z("Add subchapter"), wxDefaultPosition, wxSize(120, -1));
+  b_add_subchapter = new wxButton(this, ID_B_ADDSUBCHAPTER, Z("Add subchapter"));
 
-  b_remove_chapter = new wxButton(this, ID_B_REMOVECHAPTER, Z("Remove chapter"), wxDefaultPosition, wxSize(120, -1));
+  b_remove_chapter = new wxButton(this, ID_B_REMOVECHAPTER, Z("Remove chapter"));
 
-  b_set_values = new wxButton(this, ID_B_SETVALUES, Z("Set values"), wxDefaultPosition, wxSize(120, -1));
+  b_set_values = new wxButton(this, ID_B_SETVALUES, Z("Set values"));
   b_set_values->SetToolTip(TIP("Here you can set the values for the language and the country that you want to apply to all the "
                                "chapters below and including the currently selected entry."));
 
-  b_adjust_timecodes = new wxButton(this, ID_B_ADJUSTTIMECODES, Z("Adjust timecodes"), wxDefaultPosition, wxSize(120, -1));
+  b_adjust_timecodes = new wxButton(this, ID_B_ADJUSTTIMECODES, Z("Adjust timecodes"));
   b_adjust_timecodes->SetToolTip(TIP("Here you can adjust all the timcdoes of the selected chapter and all its childrend by a specific amount either increasing or decreasing it."));
 
   siz_fg = new wxFlexGridSizer(2);
@@ -247,11 +249,11 @@ tab_chapters::tab_chapters(wxWindow *parent,
   siz_fg->Add(tc_chapters, 1, wxGROW | wxRIGHT | wxBOTTOM, 5);
 
   siz_column = new wxBoxSizer(wxVERTICAL);
-  siz_column->Add(b_add_chapter, 0, wxBOTTOM, 3);
-  siz_column->Add(b_add_subchapter, 0, wxBOTTOM, 3);
-  siz_column->Add(b_remove_chapter, 0, wxBOTTOM, 15);
-  siz_column->Add(b_set_values, 0, wxBOTTOM, 3);
-  siz_column->Add(b_adjust_timecodes, 0, wxBOTTOM, 3);
+  siz_column->Add(b_add_chapter, 0, wxGROW | wxBOTTOM, 3);
+  siz_column->Add(b_add_subchapter, 0, wxGROW | wxBOTTOM, 3);
+  siz_column->Add(b_remove_chapter, 0, wxGROW | wxBOTTOM, 15);
+  siz_column->Add(b_set_values, 0, wxGROW | wxBOTTOM, 3);
+  siz_column->Add(b_adjust_timecodes, 0, wxGROW | wxBOTTOM, 3);
   siz_fg->Add(siz_column, 0, wxLEFT | wxBOTTOM, 5);
 
   siz_line = new wxBoxSizer(wxHORIZONTAL);
@@ -298,11 +300,11 @@ tab_chapters::tab_chapters(wxWindow *parent,
   siz_line = new wxBoxSizer(wxHORIZONTAL);
   siz_line->Add(lb_chapter_names, 1, wxGROW | wxRIGHT, 10);
 
-  b_add_chapter_name = new wxButton(this, ID_B_ADD_CHAPTERNAME, Z("Add name"), wxDefaultPosition, wxSize(100, -1));
-  b_remove_chapter_name = new wxButton(this, ID_B_REMOVE_CHAPTERNAME, Z("Remove name"), wxDefaultPosition, wxSize(100, -1));
+  b_add_chapter_name = new wxButton(this, ID_B_ADD_CHAPTERNAME, Z("Add name"));
+  b_remove_chapter_name = new wxButton(this, ID_B_REMOVE_CHAPTERNAME, Z("Remove name"));
   siz_column = new wxBoxSizer(wxVERTICAL);
-  siz_column->Add(b_add_chapter_name, 0, wxBOTTOM, 3);
-  siz_column->Add(b_remove_chapter_name, 0, 0, 0);
+  siz_column->Add(b_add_chapter_name, 0, wxGROW | wxBOTTOM, 3);
+  siz_column->Add(b_remove_chapter_name, 0, wxGROW, 0);
   siz_line->Add(siz_column, 0, 0, 0);
   siz_sb->Add(siz_line, 1, wxGROW | wxALL, 10);
 
@@ -316,7 +318,7 @@ tab_chapters::tab_chapters(wxWindow *parent,
   st_language = new wxStaticText(this, wxID_STATIC, Z("Language:"));
   siz_fg->Add(st_language, 0, wxALIGN_CENTER_VERTICAL | wxRIGHT, 10);
 
-  cob_language_code = new wxComboBox(this, ID_CB_CHAPTERSELECTLANGUAGECODE, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
+  cob_language_code = new wxMTX_COMBOBOX_TYPE(this, ID_CB_CHAPTERSELECTLANGUAGECODE, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
   for (i = 0; i < sorted_iso_codes.Count(); i++)
     cob_language_code->Append(sorted_iso_codes[i]);
   cob_language_code->SetValue(wxEmptyString);
@@ -326,7 +328,7 @@ tab_chapters::tab_chapters(wxWindow *parent,
 
   st_country = new wxStaticText(this, wxID_STATIC, Z("Country:"));
   siz_line->Add(st_country, 0, wxALIGN_CENTER_VERTICAL | wxRIGHT, 5);
-  cob_country_code = new wxComboBox(this, ID_CB_CHAPTERSELECTCOUNTRYCODE, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
+  cob_country_code = new wxMTX_COMBOBOX_TYPE(this, ID_CB_CHAPTERSELECTCOUNTRYCODE, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
   cob_country_code->Append(wxEmptyString);
   for (i = 0; cctlds[i] != NULL; i++)
     cob_country_code->Append(wxU(cctlds[i]));
@@ -536,7 +538,7 @@ tab_chapters::fix_missing_languages(EbmlMaster &master) {
 void
 tab_chapters::on_load_chapters(wxCommandEvent &evt) {
   wxFileDialog dlg(NULL, Z("Choose a chapter file"), last_open_dir, wxEmptyString,
-                   wxString::Format(Z("Chapter files (*.xml;*.txt;*.mka;*.mkv;*.cue)|*.xml;*.txt;*.mka;*.mkv;*.cue|%s"), ALLFILES.c_str()), wxOPEN);
+                   wxString::Format(Z("Chapter files (*.xml;*.txt;*.mka;*.mkv;*.cue)|*.xml;*.txt;*.mka;*.mkv;*.cue|%s"), ALLFILES.c_str()), wxFD_OPEN);
 
   if (dlg.ShowModal() == wxID_OK)
     if (load(dlg.GetPath()))
@@ -645,7 +647,7 @@ tab_chapters::on_save_chapters_to_kax_file(wxCommandEvent &evt) {
     return;
 
   wxFileDialog dlg(this, Z("Choose an output file"), last_open_dir, wxEmptyString,
-                   wxString::Format(Z("Matroska files (*.mkv;*.mka)|*.mkv;*.mka|%s"), ALLFILES.c_str()), wxSAVE);
+                   wxString::Format(Z("Matroska files (*.mkv;*.mka)|*.mkv;*.mka|%s"), ALLFILES.c_str()), wxFD_SAVE);
   if (dlg.ShowModal() != wxID_OK)
     return;
 
@@ -687,7 +689,7 @@ tab_chapters::on_save_chapters_as(wxCommandEvent &evt) {
 bool
 tab_chapters::select_file_name() {
   wxFileDialog dlg(this, Z("Choose an output file"), last_open_dir, wxEmptyString,
-                   wxString::Format(Z("Chapter files (*.xml)|*.xml|%s"), ALLFILES.c_str()), wxSAVE | wxOVERWRITE_PROMPT);
+                   wxString::Format(Z("Chapter files (*.xml)|*.xml|%s"), ALLFILES.c_str()), wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
   if(dlg.ShowModal() == wxID_OK) {
     if (kax_analyzer_c::probe(wxMB(dlg.GetPath()))) {
       wxMessageBox(Z("The file you tried to save to is a Matroska file. For this to work you have to use the 'Save to Matroska file' menu option."),
@@ -789,7 +791,7 @@ tab_chapters::verify_atom_recursively(EbmlElement *e) {
   }
   lang = string(*language);
   if ((0 == lang.size()) || !is_valid_iso639_2_code(lang.c_str())) {
-    wxMessageBox(wxString::Format(Z("The selected language '%s' for the chapter '%s'' is not a valid language code. Please select one of the predefined ones."),
+    wxMessageBox(wxString::Format(Z("The selected language '%s' for the chapter '%s' is not a valid language code. Please select one of the predefined ones."),
                                   wxU(lang.c_str()).c_str(), label.c_str()),
                  Z("Chapter verification error"), wxCENTER | wxOK | wxICON_ERROR);
     return false;
@@ -1390,7 +1392,7 @@ tab_chapters::on_adjust_timecodes(wxCommandEvent &evt) {
                         "either just a number in which case it is interpreted as the number of seconds,\n"
                         "it can be followed by the unit like 'ms' or 's' for milliseconds and seconds respectively,\n"
                         "or it can have the usual HH:MM:SS.mmm or HH:MM:SS format.\n"
-                        "Example: -00:05:23 would let all the chpaters begin\n"
+                        "Example: -00:05:23 would let all the chapters begin\n"
                         "5minutes and 23seconds earlier than now."),
                       Z("Adjust chapter timecodes"));
   strip(sadjustment);
@@ -1703,7 +1705,7 @@ tab_chapters::on_chapter_name_selected(wxCommandEvent &evt) {
   if (!id.IsOk())
     return;
   t = (chapter_node_data_c *)tc_chapters->GetItemData(id);
-  if (!t->is_atom)
+  if (!t || !t->is_atom)
     return;
   cdisplay = NULL;
   n = 0;
