@@ -56,7 +56,7 @@ tab_global::tab_global(wxWindow *parent):
 //   rb_split_by_size->SetSizeHints(0, -1);
   siz_line2 = new wxBoxSizer(wxHORIZONTAL);
   siz_line2->Add(rb_split_by_size, 0, wxALIGN_CENTER_VERTICAL | wxRIGHT, 5);
-  cob_split_by_size = new wxComboBox(this, ID_CB_SPLITBYSIZE, wxEmptyString, wxDefaultPosition, wxSize(100, -1), 0, NULL, wxCB_DROPDOWN);
+  cob_split_by_size = new wxMTX_COMBOBOX_TYPE(this, ID_CB_SPLITBYSIZE, wxEmptyString, wxDefaultPosition, wxSize(100, -1), 0, NULL, wxCB_DROPDOWN);
   cob_split_by_size->Append(wxEmptyString);
   cob_split_by_size->Append(wxT("350M"));
   cob_split_by_size->Append(wxT("650M"));
@@ -72,7 +72,7 @@ tab_global::tab_global(wxWindow *parent):
   rb_split_by_time = new wxRadioButton(this, ID_RB_SPLITBYTIME, Z("...after this duration:"));
   rb_split_by_time->Enable(false);
   siz_line2->Add(rb_split_by_time, 0, wxALIGN_CENTER_VERTICAL | wxRIGHT, 5);
-  cob_split_by_time = new wxComboBox(this, ID_CB_SPLITBYTIME, wxEmptyString, wxDefaultPosition, wxSize(100, -1), 0, NULL, wxCB_DROPDOWN);
+  cob_split_by_time = new wxMTX_COMBOBOX_TYPE(this, ID_CB_SPLITBYTIME, wxEmptyString, wxDefaultPosition, wxSize(100, -1), 0, NULL, wxCB_DROPDOWN);
   cob_split_by_time->Append(wxEmptyString);
   cob_split_by_time->Append(wxT("01:00:00"));
   cob_split_by_time->Append(wxT("1800s"));
@@ -176,7 +176,8 @@ tab_global::tab_global(wxWindow *parent):
   siz_chap_l1_l2->Add(siz_chap_l1, 1, wxGROW, 0);
 
   siz_chap_l1_l2->Add(new wxStaticText(this, -1, Z("Language:")), 0, wxALIGN_CENTER_VERTICAL | wxLEFT | wxRIGHT, 5);
-  cob_chap_language = new wxComboBox(this, ID_CB_CHAPTERLANGUAGE, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN);
+  cob_chap_language = new wxMTX_COMBOBOX_TYPE(this, ID_CB_CHAPTERLANGUAGE, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_READONLY);
+  cob_chap_language->SetMinSize(wxSize(50, -1));
   cob_chap_language->Append(wxEmptyString);
   for (i = 0; i < sorted_iso_codes.Count(); i++)
     cob_chap_language->Append(sorted_iso_codes[i]);
@@ -188,9 +189,8 @@ tab_global::tab_global(wxWindow *parent):
 
   siz_chap_l2->Add(new wxStaticText(this, -1, Z("Charset:")), 0, wxALIGN_CENTER_VERTICAL | wxLEFT | wxRIGHT, 10);
 
-  cob_chap_charset =
-    new wxComboBox(this, ID_CB_CHAPTERCHARSET, wxEmptyString, wxDefaultPosition,
-                   wxDefaultSize, 0, NULL, wxCB_DROPDOWN);
+  cob_chap_charset = new wxMTX_COMBOBOX_TYPE(this, ID_CB_CHAPTERCHARSET, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_READONLY);
+  cob_chap_charset->SetMinSize(wxSize(50, -1));
   cob_chap_charset->Append(wxEmptyString);
   for (i = 0; i < sorted_charsets.Count(); i++)
     cob_chap_charset->Append(sorted_charsets[i]);
@@ -236,7 +236,7 @@ tab_global::tab_global(wxWindow *parent):
 
 void
 tab_global::on_browse_global_tags(wxCommandEvent &evt) {
-  wxFileDialog dlg(NULL, Z("Choose the tags file"), last_open_dir, wxEmptyString, wxString::Format(Z("Tag files (*.xml)|*.xml|%s"), ALLFILES.c_str()), wxOPEN);
+  wxFileDialog dlg(NULL, Z("Choose the tags file"), last_open_dir, wxEmptyString, wxString::Format(Z("Tag files (*.xml)|*.xml|%s"), ALLFILES.c_str()), wxFD_OPEN);
   if(dlg.ShowModal() != wxID_OK)
     return;
 
@@ -247,7 +247,7 @@ tab_global::on_browse_global_tags(wxCommandEvent &evt) {
 void
 tab_global::on_browse_chapters(wxCommandEvent &evt) {
   wxFileDialog dlg(NULL, Z("Choose the chapter file"), last_open_dir, wxEmptyString,
-                   wxString::Format(Z("Chapter files (*.xml;*.txt;*.cue)|*.xml;*.txt;*.cue|%s"), ALLFILES.c_str()), wxOPEN);
+                   wxString::Format(Z("Chapter files (*.xml;*.txt;*.cue)|*.xml;*.txt;*.cue|%s"), ALLFILES.c_str()), wxFD_OPEN);
   if(dlg.ShowModal() != wxID_OK)
     return;
 
