@@ -31,6 +31,7 @@
 #include "mkvmerge.h"
 #include "mmg.h"
 #include "mmg_dialog.h"
+#include "tab_attachments.h"
 #include "tab_input.h"
 #include "tab_global.h"
 
@@ -95,22 +96,22 @@ tab_input::tab_input(wxWindow *parent):
   siz_line->Add(lb_input_files, 1, wxGROW | wxALL, STDSPACING);
 
   siz_column = new wxBoxSizer(wxVERTICAL);
-  b_add_file = new wxButton(this, ID_B_ADDFILE, Z("add"), wxDefaultPosition, wxSize(50, -1));
-  b_remove_file = new wxButton(this, ID_B_REMOVEFILE, Z("remove"), wxDefaultPosition, wxSize(50, -1));
+  b_add_file = new wxButton(this, ID_B_ADDFILE, Z("add"));
+  b_remove_file = new wxButton(this, ID_B_REMOVEFILE, Z("remove"));
   b_remove_file->Enable(false);
-  b_append_file = new wxButton(this, ID_B_APPENDFILE, Z("append"), wxDefaultPosition, wxSize(60, -1));
+  b_append_file = new wxButton(this, ID_B_APPENDFILE, Z("append"));
   b_append_file->Enable(false);
 
-  b_remove_all_files = new wxButton(this, ID_B_REMOVE_ALL_FILES, Z("rem all"), wxDefaultPosition, wxSize(60, -1));
+  b_remove_all_files = new wxButton(this, ID_B_REMOVE_ALL_FILES, Z("remove all"));
   b_remove_all_files->Enable(false);
 
-  siz_column->Add(b_add_file, 0, wxALL, STDSPACING);
-  siz_column->Add(b_remove_file, 0, wxALL, STDSPACING);
+  siz_column->Add(b_add_file, 0, wxGROW | wxALL, STDSPACING);
+  siz_column->Add(b_remove_file, 0, wxGROW | wxALL, STDSPACING);
   siz_line->Add(siz_column);
 
   siz_column = new wxBoxSizer(wxVERTICAL);
-  siz_column->Add(b_append_file, 0, wxALL, STDSPACING);
-  siz_column->Add(b_remove_all_files, 0, wxALL, STDSPACING);
+  siz_column->Add(b_append_file, 0, wxGROW | wxALL, STDSPACING);
+  siz_column->Add(b_remove_all_files, 0, wxGROW | wxALL, STDSPACING);
   siz_line->Add(siz_column);
 
   siz_all->Add(siz_line, 0, wxGROW | wxLEFT | wxRIGHT, LEFTRIGHTSPACING);
@@ -122,19 +123,13 @@ tab_input::tab_input(wxWindow *parent):
 
   cb_no_chapters = new wxCheckBox(this, ID_CB_NOCHAPTERS, Z("No chapters"));
   cb_no_chapters->SetValue(false);
-  cb_no_chapters->SetToolTip(TIP("Do not copy chapters from this file. Only applies to Matroska files."));
+  cb_no_chapters->SetToolTip(TIP("Do not copy chapters from this file. Only applies to a couple of formats (e.g. Matroska files)."));
   cb_no_chapters->Enable(false);
   siz_line->Add(cb_no_chapters, 0, wxALIGN_CENTER_VERTICAL | wxALL, STDSPACING);
 
-  cb_no_attachments = new wxCheckBox(this, ID_CB_NOATTACHMENTS, Z("No attachments"));
-  cb_no_attachments->SetValue(false);
-  cb_no_attachments->SetToolTip(TIP("Do not copy attachments from this file. Only applies to Matroska files."));
-  cb_no_attachments->Enable(false);
-  siz_line->Add(cb_no_attachments, 0, wxALIGN_CENTER_VERTICAL | wxALL, STDSPACING);
-
   cb_no_tags = new wxCheckBox(this, ID_CB_NOTAGS, Z("No tags"));
   cb_no_tags->SetValue(false);
-  cb_no_tags->SetToolTip(TIP("Do not copy tags from this file. Only applies to Matroska files."));
+  cb_no_tags->SetToolTip(TIP("Do not copy tags from this file. Only applies to a couple of formats (e.g. Matroska files)."));
   cb_no_tags->Enable(false);
   siz_line->Add(cb_no_tags, 0, wxALIGN_CENTER_VERTICAL | wxALL, STDSPACING);
   siz_all->Add(siz_line, 0, wxLEFT | wxRIGHT, LEFTRIGHTSPACING);
@@ -150,12 +145,12 @@ tab_input::tab_input(wxWindow *parent):
   clb_tracks = new wxCheckListBox(this, ID_CLB_TRACKS);
   clb_tracks->Enable(false);
   siz_line->Add(clb_tracks, 1, wxGROW | wxALIGN_TOP | wxALL, STDSPACING);
-  b_track_up = new wxButton(this, ID_B_TRACKUP, Z("up"), wxDefaultPosition, wxSize(50, -1));
+  b_track_up = new wxButton(this, ID_B_TRACKUP, Z("up"));
   b_track_up->Enable(false);
-  siz_column->Add(b_track_up, 0, wxALL, STDSPACING);
-  b_track_down = new wxButton(this, ID_B_TRACKDOWN, Z("down"), wxDefaultPosition, wxSize(50, -1));
+  siz_column->Add(b_track_up, 0, wxGROW | wxALL, STDSPACING);
+  b_track_down = new wxButton(this, ID_B_TRACKDOWN, Z("down"));
   b_track_down->Enable(false);
-  siz_column->Add(b_track_down, 0, wxALL, STDSPACING);
+  siz_column->Add(b_track_down, 0, wxGROW | wxALL, STDSPACING);
   siz_line->Add(siz_column);
   siz_all->Add(siz_line, 3, wxGROW | wxLEFT | wxRIGHT, LEFTRIGHTSPACING);
 
@@ -277,7 +272,7 @@ tab_input::select_file(bool append) {
 
   media_files.Printf(Z("All supported media files|%s%s|%s"), a_exts.c_str(), rest.c_str(), ALLFILES.c_str());
 
-  wxFileDialog dlg(NULL, append ? Z("Choose an input file to append") : Z("Choose an input file to add"), last_open_dir, wxEmptyString, media_files, wxOPEN | wxMULTIPLE);
+  wxFileDialog dlg(NULL, append ? Z("Choose an input file to append") : Z("Choose an input file to add"), last_open_dir, wxEmptyString, media_files, wxFD_OPEN | wxFD_MULTIPLE);
   if(dlg.ShowModal() != wxID_OK)
     return;
 
@@ -302,7 +297,6 @@ tab_input::on_append_file(wxCommandEvent &evt) {
 void
 tab_input::add_file(const wxString &file_name,
                     bool append) {
-  mmg_file_t file;
   wxString name, command, id, type, exact, video_track_name, opt_file_name;
   wxArrayString output, errors;
   vector<wxString> args, pair;
@@ -372,7 +366,7 @@ tab_input::add_file(const wxString &file_name,
     return;
 
   } else if (0 < result) {
-    name.Printf(Z("File identification failed. Return code: %d. Errno: %d (%s). Make sure that you've selected a mkvmerge executable on the 'settings' tab."),
+    name.Printf(Z("File identification failed. Return code: %d. Errno: %d (%s). Make sure that you've selected a mkvmerge executable in the settings dialog."),
                 result, errno, wxUCS(strerror(errno)));
     break_line(name, 60);
     wxMessageBox(name, Z("File identification failed"), wxOK | wxCENTER | wxICON_ERROR);
@@ -386,13 +380,15 @@ tab_input::add_file(const wxString &file_name,
       delay_from_file_name = re_delay.GetMatch(file_name, 1);
   }
 
+  mmg_file_cptr file           = mmg_file_cptr(new mmg_file_t);
+
   default_audio_track_found    = -1 != default_track_checked('a');
   default_video_track_found    = -1 != default_track_checked('v');
   default_subtitle_track_found = -1 != default_track_checked('s');
   for (i = 0; i < output.Count(); i++) {
     if (output[i].Find(wxT("Track")) == 0) {
       wxString info;
-      mmg_track_ptr track(new mmg_track_t);
+      mmg_track_cptr track(new mmg_track_t);
 
       id = output[i].AfterFirst(wxT(' ')).AfterFirst(wxT(' ')).
         BeforeFirst(wxT(':'));
@@ -473,9 +469,9 @@ tab_input::add_file(const wxString &file_name,
 
       track->appending = append;
 
-      file.tracks.push_back(track);
+      file->tracks.push_back(track);
 
-      if (   (FILE_TYPE_AVC_ES == file.container)
+      if (   (FILE_TYPE_AVC_ES == file->container)
           && ('v' == track->type)
           && (track->ctype.Find(wxT("MPEG-4 part 10 ES")) >= 0)
           && (!avc_es_fps_warning_shown || mdlg->options.warn_usage)) {
@@ -497,62 +493,87 @@ tab_input::add_file(const wxString &file_name,
       wxString info      = output[i].Mid(pos + 11).AfterFirst(wxT('[')).BeforeLast(wxT(']'));
 
       if (container == wxT("AAC"))
-        file.container = FILE_TYPE_AAC;
+        file->container = FILE_TYPE_AAC;
       else if (container == wxT("AC3"))
-        file.container = FILE_TYPE_AC3;
+        file->container = FILE_TYPE_AC3;
       else if (container == wxT("AVC/h.264"))
-        file.container = FILE_TYPE_AVC_ES;
+        file->container = FILE_TYPE_AVC_ES;
       else if (container == wxT("AVI"))
-        file.container = FILE_TYPE_AVI;
+        file->container = FILE_TYPE_AVI;
       else if (container == wxT("Dirac elementary stream"))
-        file.container = FILE_TYPE_DIRAC;
+        file->container = FILE_TYPE_DIRAC;
       else if (container == wxT("DTS"))
-        file.container = FILE_TYPE_DTS;
+        file->container = FILE_TYPE_DTS;
       else if (container == wxT("Matroska"))
-        file.container = FILE_TYPE_MATROSKA;
+        file->container = FILE_TYPE_MATROSKA;
       else if (container == wxT("MP2/MP3"))
-        file.container = FILE_TYPE_MP3;
+        file->container = FILE_TYPE_MP3;
       else if (container == wxT("Ogg/OGM"))
-        file.container = FILE_TYPE_OGM;
+        file->container = FILE_TYPE_OGM;
       else if (container == wxT("Quicktime/MP4"))
-        file.container = FILE_TYPE_QTMP4;
+        file->container = FILE_TYPE_QTMP4;
       else if (container == wxT("RealMedia"))
-        file.container = FILE_TYPE_REAL;
+        file->container = FILE_TYPE_REAL;
       else if (container == wxT("SRT"))
-        file.container = FILE_TYPE_SRT;
+        file->container = FILE_TYPE_SRT;
       else if (container == wxT("SSA/ASS"))
-        file.container = FILE_TYPE_SSA;
+        file->container = FILE_TYPE_SSA;
       else if (container == wxT("VC1 elementary stream"))
-        file.container = FILE_TYPE_VC1;
+        file->container = FILE_TYPE_VC1;
       else if (container == wxT("VobSub"))
-        file.container = FILE_TYPE_VOBSUB;
+        file->container = FILE_TYPE_VOBSUB;
       else if (container == wxT("WAV"))
-        file.container = FILE_TYPE_WAV;
+        file->container = FILE_TYPE_WAV;
       else
-        file.container = FILE_TYPE_IS_UNKNOWN;
+        file->container = FILE_TYPE_IS_UNKNOWN;
 
       if (info.length() > 0) {
         args = split(info, wxU(" "));
         for (k = 0; k < args.size(); k++) {
           pair = split(args[k], wxU(":"), 2);
           if ((pair.size() == 2) && (pair[0] == wxT("title"))) {
-            file.title = from_utf8(unescape(pair[1]));
-            file.title_was_present = true;
+            file->title = from_utf8(unescape(pair[1]));
+            file->title_was_present = true;
             title_was_present = true;
           }
         }
       }
+
+    } else if (output[i].Find(wxT("Attachment")) == 0) {
+      mmg_attached_file_cptr a = mmg_attached_file_cptr(new mmg_attached_file_t);
+
+      wxRegEx re_att_base(       wxT("^Attachment *ID ([[:digit:]]+): *type *\"([^\"]+)\", *size *([[:digit:]]+)"), wxRE_ICASE);
+      wxRegEx re_att_description(wxT("description *\"([^\"]+)\""),                                                  wxRE_ICASE);
+      wxRegEx re_att_name(       wxT("name *\"([^\"]+)\""),                                                         wxRE_ICASE);
+
+      if (re_att_base.Matches(output[i])) {
+        re_att_base.GetMatch(output[i], 1).ToLong(&a->id);
+        re_att_base.GetMatch(output[i], 3).ToLong(&a->size);
+        a->mime_type = unescape(re_att_base.GetMatch(output[i], 2));
+
+        if (re_att_description.Matches(output[i]))
+          a->description = unescape(re_att_description.GetMatch(output[i], 1));
+        if (re_att_name.Matches(output[i]))
+          a->name = unescape(re_att_name.GetMatch(output[i], 1));
+
+        a->source = file.get();
+
+        file->attached_files.push_back(a);
+
+        wxLogMessage(wxT("Attached file ID %ld MIME type '%s' size %ld description '%s' name '%s'"),
+                     a->id, a->mime_type.c_str(), a->size, a->description.c_str(), a->name.c_str());
+      }
     }
   }
 
-  if (file.tracks.empty()) {
+  if (file->tracks.empty()) {
     wxMessageBox(wxString::Format(Z("The input file '%s' does not contain any tracks."), file_name.c_str()), Z("No tracks found"));
     return;
   }
 
-  // Look for a place to insert the new file. If the file is only "added",
+  // Look for a place to insert the new file-> If the file is only "added",
   // then it will be added to the back of the list. If it is "appended",
-  // then it should be inserted right after the currently selected file.
+  // then it should be inserted right after the currently selected file->
   if (!append)
     new_file_pos = lb_input_files->GetCount();
   else {
@@ -562,18 +583,18 @@ tab_input::add_file(const wxString &file_name,
     else {
       do {
         ++new_file_pos;
-      } while ((files.size() > new_file_pos) && files[new_file_pos].appending);
+      } while ((files.size() > new_file_pos) && files[new_file_pos]->appending);
     }
   }
 
   name.Printf(wxT("%s%s (%s)"), append ? wxT("++> ") : wxEmptyString, file_name.AfterLast(wxT(PSEP)).c_str(), file_name.BeforeLast(wxT(PSEP)).c_str());
   lb_input_files->Insert(name, new_file_pos);
 
-  file.file_name = file_name;
-  mdlg->set_title_maybe(file.title);
-  if ((file.container == FILE_TYPE_OGM) && (video_track_name.Length() > 0))
+  file->file_name = file_name;
+  mdlg->set_title_maybe(file->title);
+  if ((file->container == FILE_TYPE_OGM) && (video_track_name.Length() > 0))
     mdlg->set_title_maybe(video_track_name);
-  file.appending = append;
+  file->appending = append;
   files.insert(files.begin() + new_file_pos, file);
 
   // After inserting the file the "source" index is wrong for all files
@@ -585,12 +606,12 @@ tab_input::add_file(const wxString &file_name,
   if (name.StartsWith(wxT("++> ")))
     name.Remove(0, 4);
 
-  for (i = 0; i < file.tracks.size(); i++) {
+  for (i = 0; i < file->tracks.size(); i++) {
     string format;
     wxString label;
     int new_track_pos;
 
-    mmg_track_ptr &t = file.tracks[i];
+    mmg_track_cptr &t = file->tracks[i];
     t->enabled = true;
     t->source  = new_file_pos;
 
@@ -607,7 +628,7 @@ tab_input::add_file(const wxString &file_name,
     // If the file is "appended" then it should be put to the end of the
     // chain of tracks being appended. The n'th track from this new file
     // should be appended to the n'th track of the "old" file this new file is
-    // appended to. So first I have to find the n'th track of the "old" file.
+    // appended to. So first I have to find the n'th track of the "old" file->
     // Then I have to skip over all the other tracks that are already appended
     // to that n'th track. The insertion point is right after that.
     if (append) {
@@ -635,7 +656,11 @@ tab_input::add_file(const wxString &file_name,
     clb_tracks->Check(new_track_pos, true);
   }
 
-  mdlg->set_output_maybe(file.file_name);
+  if (!file->attached_files.empty())
+    for (i = 0; file->attached_files.size() > i; ++i)
+      mdlg->attachments_page->add_attached_file(file->attached_files[i]);
+
+  mdlg->set_output_maybe(file->file_name);
 
   st_tracks->Enable(true);
   clb_tracks->Enable(true);
@@ -651,7 +676,7 @@ tab_input::on_remove_file(wxCommandEvent &evt) {
   if (-1 == selected_file)
     return;
 
-  mmg_file_t *f = &files[selected_file];
+  mmg_file_cptr &f = files[selected_file];
 
   // Files may not be removed if something else is still being appended to
   // them.
@@ -688,12 +713,13 @@ tab_input::on_remove_file(wxCommandEvent &evt) {
   if ((f->title != wxEmptyString) && f->title_was_present && (f->title == mdlg->global_page->tc_title->GetValue()))
     mdlg->global_page->tc_title->SetValue(wxEmptyString);
 
+  mdlg->attachments_page->remove_attached_files_for(files[selected_file]);
+
   files.erase(files.begin() + selected_file);
   lb_input_files->Delete(selected_file);
   selected_file = lb_input_files->GetSelection();
   st_file_options->Enable(-1 != selected_file);
   cb_no_chapters->Enable(-1 != selected_file);
-  cb_no_attachments->Enable(-1 != selected_file);
   cb_no_tags->Enable(-1 != selected_file);
   b_remove_file->Enable(-1 != selected_file);
   b_remove_all_files->Enable(-1 != selected_file);
@@ -716,6 +742,8 @@ void
 tab_input::on_remove_all_files(wxCommandEvent &evt) {
   dont_copy_values_now = true;
 
+  mdlg->attachments_page->remove_all_attached_files();
+
   lb_input_files->Clear();
   clb_tracks->Clear();
 
@@ -728,7 +756,6 @@ tab_input::on_remove_all_files(wxCommandEvent &evt) {
   clb_tracks->Enable(false);
   st_file_options->Enable(false);
   cb_no_chapters->Enable(false);
-  cb_no_attachments->Enable(false);
   cb_no_tags->Enable(false);
   b_remove_file->Enable(false);
   b_remove_all_files->Enable(false);
@@ -817,26 +844,22 @@ tab_input::on_file_selected(wxCommandEvent &evt) {
   b_remove_file->Enable(true);
   b_append_file->Enable(true);
 
-  int old_track  = selected_track;
-  selected_track = -1;
-  mmg_file_t *f  = &files[new_sel];
+  int old_track    = selected_track;
+  selected_track   = -1;
+  mmg_file_cptr &f = files[new_sel];
 
   if (FILE_TYPE_MATROSKA == f->container) {
     st_file_options->Enable(true);
     cb_no_chapters->Enable(true);
-    cb_no_attachments->Enable(true);
     cb_no_tags->Enable(true);
     cb_no_chapters->SetValue(f->no_chapters);
-    cb_no_attachments->SetValue(f->no_attachments);
     cb_no_tags->SetValue(f->no_tags);
 
   } else {
     st_file_options->Enable(false);
     cb_no_chapters->Enable(false);
-    cb_no_attachments->Enable(false);
     cb_no_tags->Enable(false);
     cb_no_chapters->SetValue(false);
-    cb_no_attachments->SetValue(false);
     cb_no_tags->SetValue(false);
   }
 
@@ -847,19 +870,13 @@ tab_input::on_file_selected(wxCommandEvent &evt) {
 void
 tab_input::on_nochapters_clicked(wxCommandEvent &evt) {
   if (dont_copy_values_now || (-1 != selected_file))
-    files[selected_file].no_chapters = cb_no_chapters->GetValue();
-}
-
-void
-tab_input::on_noattachments_clicked(wxCommandEvent &evt) {
-  if (dont_copy_values_now || (-1 != selected_file))
-    files[selected_file].no_attachments = cb_no_attachments->GetValue();
+    files[selected_file]->no_chapters = cb_no_chapters->GetValue();
 }
 
 void
 tab_input::on_notags_clicked(wxCommandEvent &evt) {
   if (dont_copy_values_now || (-1 != selected_file))
-    files[selected_file].no_tags = cb_no_tags->GetValue();
+    files[selected_file]->no_tags = cb_no_tags->GetValue();
 }
 
 void
@@ -889,18 +906,17 @@ tab_input::on_track_selected(wxCommandEvent &evt) {
 
   ti_general->cob_language->SetValue(lang);
   ti_general->tc_track_name->SetValue(t->track_name);
-  ti_general->cob_cues->SetValue(t->cues);
+  ti_general->cob_cues->SetValue(ti_general->cob_cues_translations.to_translated(t->cues));
   ti_format->tc_delay->SetValue(t->delay);
   ti_format->tc_stretch->SetValue(t->stretch);
-  ti_format->cob_sub_charset->SetValue(t->sub_charset);
-  ti_general->tc_tags->SetValue(t->tags);
+  ti_format->cob_sub_charset->SetValue(ti_format->cob_sub_charset_translations.to_translated(t->sub_charset));
   ti_general->cob_default->SetSelection(t->default_track);
   ti_format->cb_aac_is_sbr->SetValue(t->aac_is_sbr);
   set_combobox_selection(ti_format->cob_aspect_ratio, t->aspect_ratio);
   ti_format->tc_display_width->SetValue(t->dwidth);
   ti_format->tc_display_height->SetValue(t->dheight);
   selected_track = new_sel;
-  ti_format->cob_compression->SetValue(t->compression);
+  ti_format->cob_compression->SetValue(ti_format->cob_compression_translations.to_translated(t->compression));
   ti_general->tc_timecodes->SetValue(t->timecodes);
   set_combobox_selection(ti_format->cob_fourcc, t->fourcc);
   set_combobox_selection(ti_format->cob_fps, t->fps);
@@ -936,10 +952,8 @@ tab_input::on_file_new(wxCommandEvent &evt) {
   b_remove_file->Enable(false);
   st_file_options->Enable(false);
   cb_no_chapters->Enable(false);
-  cb_no_attachments->Enable(false);
   cb_no_tags->Enable(false);
   cb_no_chapters->SetValue(false);
-  cb_no_attachments->SetValue(false);
   cb_no_tags->SetValue(false);
   b_track_up->Enable(false);
   b_track_down->Enable(false);
@@ -952,7 +966,7 @@ tab_input::save(wxConfigBase *cfg) {
 
   unsigned int fidx;
   for (fidx = 0; fidx < files.size(); fidx++) {
-    mmg_file_t *f = &files[fidx];
+    mmg_file_cptr &f = files[fidx];
     wxString s;
     s.Printf(wxT("file %u"), fidx);
     cfg->SetPath(s);
@@ -968,7 +982,7 @@ tab_input::save(wxConfigBase *cfg) {
     for (tidx = 0; tidx < f->tracks.size(); tidx++) {
       string format;
 
-      mmg_track_ptr &t = f->tracks[tidx];
+      mmg_track_cptr &t = f->tracks[tidx];
       s.Printf(wxT("track %u"), tidx);
       cfg->SetPath(s);
 
@@ -1006,6 +1020,23 @@ tab_input::save(wxConfigBase *cfg) {
       cfg->SetPath(wxT(".."));
     }
 
+    cfg->Write(wxT("number_of_attached_files"), (int)f->attached_files.size());
+    unsigned int afidx;
+    for (afidx = 0; f->attached_files.size() > afidx; ++afidx) {
+      mmg_attached_file_cptr &a = f->attached_files[afidx];
+
+      cfg->SetPath(wxString::Format(wxT("attached_file %u"), afidx));
+
+      cfg->Write(wxT("id"),          a->id);
+      cfg->Write(wxT("size"),        a->size);
+      cfg->Write(wxT("name"),        a->name);
+      cfg->Write(wxT("mime_type"),   a->mime_type);
+      cfg->Write(wxT("description"), a->description);
+      cfg->Write(wxT("enabled"),     a->enabled);
+
+      cfg->SetPath(wxT(".."));
+    }
+
     cfg->SetPath(wxT(".."));
   }
   cfg->Write(wxT("track_order"), create_track_order(true));
@@ -1041,7 +1072,7 @@ tab_input::load(wxConfigBase *cfg,
   wxString c, track_order;
   long fidx;
   for (fidx = 0; fidx < (long)num_files; fidx++) {
-    mmg_file_t fi;
+    mmg_file_cptr fi = mmg_file_cptr(new mmg_file_t);
 
     wxString s;
     s.Printf(wxT("file %u"), fidx);
@@ -1053,20 +1084,20 @@ tab_input::load(wxConfigBase *cfg,
       continue;
     }
 
-    if (!cfg->Read(wxT("file_name"), &fi.file_name)) {
+    if (!cfg->Read(wxT("file_name"), &fi->file_name)) {
       cfg->SetPath(wxT(".."));
       continue;
     }
-    cfg->Read(wxT("title"),          &fi.title);
-    cfg->Read(wxT("container"),      &fi.container);
-    cfg->Read(wxT("no_chapters"),    &fi.no_chapters,    false);
-    cfg->Read(wxT("no_attachments"), &fi.no_attachments, false);
-    cfg->Read(wxT("no_tags"),        &fi.no_tags,        false);
-    cfg->Read(wxT("appending"),      &fi.appending,      false);
+    cfg->Read(wxT("title"),          &fi->title);
+    cfg->Read(wxT("container"),      &fi->container);
+    cfg->Read(wxT("no_chapters"),    &fi->no_chapters,    false);
+    cfg->Read(wxT("no_attachments"), &fi->no_attachments, false);
+    cfg->Read(wxT("no_tags"),        &fi->no_tags,        false);
+    cfg->Read(wxT("appending"),      &fi->appending,      false);
 
     long tidx;
     for (tidx = 0; tidx < (long)num_tracks; tidx++) {
-      mmg_track_ptr tr(new mmg_track_t);
+      mmg_track_cptr tr(new mmg_track_t);
       bool dummy = false;
 
       s.Printf(wxT("track %ld"), tidx);
@@ -1118,14 +1149,38 @@ tab_input::load(wxConfigBase *cfg,
         track_order += wxT(",");
       track_order += wxString::Format(wxUCS(format.c_str()), files.size(), tr->id);
 
-      fi.tracks.push_back(tr);
+      fi->tracks.push_back(tr);
       cfg->SetPath(wxT(".."));
     }
 
-    if (!fi.tracks.empty()) {
-      s = fi.file_name.BeforeLast(PSEP);
-      c = fi.file_name.AfterLast(PSEP);
-      lb_input_files->Append(wxString::Format(wxT("%s%s (%s)"), fi.appending ? wxT("++> ") : wxEmptyString, c.c_str(), s.c_str()));
+    int num_attached_files;
+    if (cfg->Read(wxT("number_of_attached_files"), &num_attached_files) && (0 < num_attached_files)) {
+      int i;
+      for (i = 0; num_attached_files > i; ++i) {
+        cfg->SetPath(wxString::Format(wxT("attached_file %u"), i));
+
+        mmg_attached_file_cptr a = mmg_attached_file_cptr(new mmg_attached_file_t);
+
+        cfg->Read(wxT("id"),          &a->id);
+        cfg->Read(wxT("size"),        &a->size);
+        cfg->Read(wxT("name"),        &a->name);
+        cfg->Read(wxT("mime_type"),   &a->mime_type);
+        cfg->Read(wxT("description"), &a->description);
+        cfg->Read(wxT("enabled"),     &a->enabled, false);
+
+        cfg->SetPath(wxT(".."));
+
+        if (0 != a->id) {
+          a->source = fi.get();
+          fi->attached_files.push_back(a);
+        }
+      }
+    }
+
+    if (!fi->tracks.empty()) {
+      s = fi->file_name.BeforeLast(PSEP);
+      c = fi->file_name.AfterLast(PSEP);
+      lb_input_files->Append(wxString::Format(wxT("%s%s (%s)"), fi->appending ? wxT("++> ") : wxEmptyString, c.c_str(), s.c_str()));
       files.push_back(fi);
     }
 
@@ -1156,8 +1211,8 @@ tab_input::load(wxConfigBase *cfg,
                 "(Problem occured in tab_input::load(), #2)"));
       bool found = false;
       int j;
-      for (j = 0; j < files[fidx].tracks.size(); j++)
-        if (files[fidx].tracks[j]->id == tidx) {
+      for (j = 0; j < files[fidx]->tracks.size(); j++)
+        if (files[fidx]->tracks[j]->id == tidx) {
           found = true;
           tidx = j;
         }
@@ -1167,12 +1222,12 @@ tab_input::load(wxConfigBase *cfg,
                 "a bug in mmg. Please report this to the author\n"
                 "Moritz Bunkus <moritz@bunkus.org>\n\n"
                 "(Problem occured in tab_input::load(), #3)"));
-      mmg_track_ptr &t = files[fidx].tracks[tidx];
+      mmg_track_cptr &t = files[fidx]->tracks[tidx];
       tracks.push_back(t.get());
 
       fix_format(Y("%s%s (ID %lld, type: %s) from %s"), format);
-      wxString name  = files[fidx].file_name.AfterLast(wxT(PSEP));
-      name          += wxT(" (") + files[fidx].file_name.BeforeLast(wxT(PSEP)) + wxT(")");
+      wxString name  = files[fidx]->file_name.AfterLast(wxT(PSEP));
+      name          += wxT(" (") + files[fidx]->file_name.BeforeLast(wxT(PSEP)) + wxT(")");
       wxString type  = t->type == 'a' ? Z("audio")
                      : t->type == 'v' ? Z("video")
                      : t->type == 's' ? Z("subtitles")
@@ -1211,10 +1266,10 @@ tab_input::validate_settings() {
   bool tracks_selected = false;
   unsigned int fidx;
   for (fidx = 0; fidx < files.size(); fidx++) {
-    mmg_file_t *f = &files[fidx];
+    mmg_file_cptr &f = files[fidx];
 
     for (tidx = 0; tidx < f->tracks.size(); tidx++) {
-      mmg_track_ptr &t = f->tracks[tidx];
+      mmg_track_cptr &t = f->tracks[tidx];
       if (!t->enabled)
         continue;
 
@@ -1347,7 +1402,6 @@ BEGIN_EVENT_TABLE(tab_input, wxPanel)
   EVT_CHECKLISTBOX(ID_CLB_TRACKS,   tab_input::on_track_enabled)
 
   EVT_CHECKBOX(ID_CB_NOCHAPTERS,    tab_input::on_nochapters_clicked)
-  EVT_CHECKBOX(ID_CB_NOATTACHMENTS, tab_input::on_noattachments_clicked)
   EVT_CHECKBOX(ID_CB_NOTAGS,        tab_input::on_notags_clicked)
 
   EVT_TIMER(ID_T_INPUTVALUES,       tab_input::on_value_copy_timer)
