@@ -64,7 +64,7 @@ class tab_input_general: public wxPanel {
   DECLARE_CLASS(tab_input_general);
   DECLARE_EVENT_TABLE();
 public:
-  wxComboBox *cob_default, *cob_language, *cob_cues;
+  wxMTX_COMBOBOX_TYPE *cob_default, *cob_language, *cob_cues;
   wxTextCtrl *tc_track_name, *tc_tags, *tc_timecodes;
   wxButton *b_browse_tags, *b_browse_timecodes;
 
@@ -73,6 +73,9 @@ public:
 
   tab_input *input;
 
+  translation_table_c cob_cues_translations;
+  translation_table_c cob_default_translations;
+
 public:
   tab_input_general(wxWindow *parent, tab_input *ti);
 
@@ -96,8 +99,7 @@ class tab_input_format: public wxPanel {
   DECLARE_EVENT_TABLE();
 public:
   wxCheckBox *cb_aac_is_sbr;
-  wxComboBox *cob_sub_charset, *cob_aspect_ratio, *cob_fourcc, *cob_compression;
-  wxComboBox *cob_stereo_mode, *cob_fps, *cob_nalu_size_length;
+  wxMTX_COMBOBOX_TYPE *cob_sub_charset, *cob_aspect_ratio, *cob_fourcc, *cob_compression, *cob_stereo_mode, *cob_fps, *cob_nalu_size_length;
   wxTextCtrl *tc_delay, *tc_stretch;
   wxRadioButton *rb_aspect_ratio, *rb_display_dimensions;
   wxTextCtrl *tc_display_width, *tc_display_height;
@@ -108,6 +110,9 @@ public:
 
   tab_input *input;
 
+  translation_table_c cob_sub_charset_translations;
+  translation_table_c cob_compression_translations;
+
 public:
   tab_input_format(wxWindow *parent, tab_input *ti);
 
@@ -159,7 +164,7 @@ public:
   wxListBox *lb_input_files;
   wxButton *b_add_file, *b_remove_file, *b_remove_all_files;
   wxButton *b_track_up, *b_track_down, *b_append_file;
-  wxCheckBox *cb_no_chapters, *cb_no_attachments, *cb_no_tags;
+  wxCheckBox *cb_no_chapters, *cb_no_tags;
   wxCheckListBox *clb_tracks;
   wxStaticText *st_file_options, *st_tracks;
   wxNotebook *nb_options;
@@ -185,7 +190,6 @@ public:
   void on_track_selected(wxCommandEvent &evt);
   void on_track_enabled(wxCommandEvent &evt);
   void on_nochapters_clicked(wxCommandEvent &evt);
-  void on_noattachments_clicked(wxCommandEvent &evt);
   void on_notags_clicked(wxCommandEvent &evt);
   void on_value_copy_timer(wxTimerEvent &evt);
   void on_file_new(wxCommandEvent &evt);
