@@ -57,7 +57,7 @@ tab_input_general::tab_input_general(wxWindow *parent,
   st_language->Enable(false);
   siz_fg->Add(st_language, 0, wxALIGN_CENTER_VERTICAL | wxALL, STDSPACING);
 
-  cob_language = new wxComboBox(this, ID_CB_LANGUAGE, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
+  cob_language = new wxMTX_COMBOBOX_TYPE(this, ID_CB_LANGUAGE, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
   cob_language->SetToolTip(TIP("Language for this track. Select one of the ISO639-2 language codes."));
   siz_fg->Add(cob_language, 1, wxGROW | wxALL, STDSPACING);
 
@@ -65,7 +65,7 @@ tab_input_general::tab_input_general(wxWindow *parent,
   st_cues->Enable(false);
   siz_fg->Add(st_cues, 0, wxALIGN_CENTER_VERTICAL | wxALL, STDSPACING);
 
-  cob_cues = new wxComboBox(this, ID_CB_CUES, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
+  cob_cues = new wxMTX_COMBOBOX_TYPE(this, ID_CB_CUES, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
   cob_cues->SetToolTip(TIP("Selects for which blocks mkvmerge will produce index entries ( = cue entries). \"default\" is a good choice for almost all situations."));
   cob_cues->SetSizeHints(0, -1);
   siz_fg->Add(cob_cues, 1, wxGROW | wxALIGN_CENTER_VERTICAL | wxALL, STDSPACING);
@@ -73,7 +73,7 @@ tab_input_general::tab_input_general(wxWindow *parent,
   st_default = new wxStaticText(this, wxID_STATIC, Z("Default track flag:"));
   siz_fg->Add(st_default, 0, wxALIGN_CENTER_VERTICAL | wxALL, STDSPACING);
 
-  cob_default = new wxComboBox(this, ID_CB_MAKEDEFAULT, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
+  cob_default = new wxMTX_COMBOBOX_TYPE(this, ID_CB_MAKEDEFAULT, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, NULL, wxCB_DROPDOWN | wxCB_READONLY);
   cob_default->SetToolTip(TIP("Make this track the default track for its type (audio, video, subtitles). Players should prefer tracks with the default track flag set."));
   siz_fg->Add(cob_default, 1, wxGROW | wxALIGN_CENTER_VERTICAL | wxALL, STDSPACING);
 
@@ -115,17 +115,25 @@ tab_input_general::tab_input_general(wxWindow *parent,
 
 void
 tab_input_general::setup_cues() {
-  cob_cues->Append(Z("default"));
-  cob_cues->Append(Z("only for I frames"));
-  cob_cues->Append(Z("for all frames"));
-  cob_cues->Append(Z("none"));
+  cob_cues_translations.add(wxT("default"),           Z("default"));
+  cob_cues_translations.add(wxT("only for I frames"), Z("only for I frames"));
+  cob_cues_translations.add(wxT("for all frames"),    Z("for all frames"));
+  cob_cues_translations.add(wxT("none"),              Z("none"));
+
+  int i;
+  for (i = 0; cob_cues_translations.entries.size() > i; ++i)
+    cob_cues->Append(cob_cues_translations.entries[i].translated);
 }
 
 void
 tab_input_general::setup_default_track() {
-  cob_default->Append(Z("default"));
-  cob_default->Append(Z("yes"));
-  cob_default->Append(Z("no"));
+  cob_default_translations.add(wxT("default"), Z("default"));
+  cob_default_translations.add(wxT("yes"),     Z("yes"));
+  cob_default_translations.add(wxT("no"),      Z("no"));
+
+  int i;
+  for (i = 0; cob_default_translations.entries.size() > i; ++i)
+    cob_default->Append(cob_default_translations.entries[i].translated);
 }
 
 void
@@ -242,7 +250,7 @@ tab_input_general::on_cues_selected(wxCommandEvent &evt) {
   if (input->dont_copy_values_now || (input->selected_track == -1))
     return;
 
-  tracks[input->selected_track]->cues = cob_cues->GetStringSelection();
+  tracks[input->selected_track]->cues = cob_cues_translations.to_english(cob_cues->GetStringSelection());
 }
 
 void
@@ -250,7 +258,7 @@ tab_input_general::on_browse_tags(wxCommandEvent &evt) {
   if (input->selected_track == -1)
     return;
 
-  wxFileDialog dlg(NULL, Z("Choose a tag file"), last_open_dir, wxEmptyString, wxString(Z("Tag files (*.xml;*.txt)|*.xml;*.txt|%s"), ALLFILES.c_str()), wxOPEN);
+  wxFileDialog dlg(NULL, Z("Choose a tag file"), last_open_dir, wxEmptyString, wxString(Z("Tag files (*.xml;*.txt)|*.xml;*.txt|%s"), ALLFILES.c_str()), wxFD_OPEN);
   if(dlg.ShowModal() != wxID_OK)
     return;
 
@@ -264,7 +272,7 @@ tab_input_general::on_browse_timecodes_clicked(wxCommandEvent &evt) {
   if (input->selected_track == -1)
     return;
 
-  wxFileDialog dlg(NULL, Z("Choose a timecodes file"), last_open_dir, wxEmptyString, wxString::Format(Z("Timecode files (*.tmc;*.txt)|*.tmc;*.txt|%s"), ALLFILES.c_str()), wxOPEN);
+  wxFileDialog dlg(NULL, Z("Choose a timecodes file"), last_open_dir, wxEmptyString, wxString::Format(Z("Timecode files (*.tmc;*.txt)|*.tmc;*.txt|%s"), ALLFILES.c_str()), wxFD_OPEN);
   if(dlg.ShowModal() != wxID_OK)
     return;
 
